package com.airbnb.lottie;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.util.JsonReader;
import android.util.Log;
import com.airbnb.lottie.model.LottieCompositionCache;
import com.airbnb.lottie.network.NetworkFetcher;
import com.airbnb.lottie.parser.LottieCompositionParser;
import com.airbnb.lottie.utils.Utils;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.StringReader;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.Callable;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;
import org.json.JSONObject;

/* loaded from: classes.dex */
public class LottieCompositionFactory {
    private static final Map<String, LottieTask<LottieComposition>> taskCache = new HashMap();

    private LottieCompositionFactory() {
    }

    public static LottieTask<LottieComposition> fromUrl(Context context, String str) {
        return NetworkFetcher.fetch(context, str);
    }

    public static LottieResult<LottieComposition> fromUrlSync(Context context, String str) {
        return NetworkFetcher.fetchSync(context, str);
    }

    /* renamed from: com.airbnb.lottie.LottieCompositionFactory$1 */
    class AnonymousClass1 implements Callable<LottieResult<LottieComposition>> {
        final /* synthetic */ Context val$appContext;
        final /* synthetic */ String val$fileName;

        AnonymousClass1(Context context, String str) {
            r1 = context;
            r2 = str;
        }

        @Override // java.util.concurrent.Callable
        public LottieResult<LottieComposition> call() {
            return LottieCompositionFactory.fromAssetSync(r1, r2);
        }
    }

    public static LottieTask<LottieComposition> fromAsset(Context context, String str) {
        return cache(str, new Callable<LottieResult<LottieComposition>>() { // from class: com.airbnb.lottie.LottieCompositionFactory.1
            final /* synthetic */ Context val$appContext;
            final /* synthetic */ String val$fileName;

            AnonymousClass1(Context context2, String str2) {
                r1 = context2;
                r2 = str2;
            }

            @Override // java.util.concurrent.Callable
            public LottieResult<LottieComposition> call() {
                return LottieCompositionFactory.fromAssetSync(r1, r2);
            }
        });
    }

    public static LottieResult<LottieComposition> fromAssetSync(Context context, String str) {
        try {
            String str2 = "asset_" + str;
            if (str.endsWith(".zip")) {
                return fromZipStreamSync(new ZipInputStream(context.getAssets().open(str)), str2);
            }
            return fromJsonInputStreamSync(context.getAssets().open(str), str2);
        } catch (IOException e) {
            return new LottieResult<>((Throwable) e);
        }
    }

    /* renamed from: com.airbnb.lottie.LottieCompositionFactory$2 */
    class AnonymousClass2 implements Callable<LottieResult<LottieComposition>> {
        final /* synthetic */ Context val$appContext;
        final /* synthetic */ int val$rawRes;

        AnonymousClass2(Context context, int i) {
            r1 = context;
            r2 = i;
        }

        @Override // java.util.concurrent.Callable
        public LottieResult<LottieComposition> call() {
            return LottieCompositionFactory.fromRawResSync(r1, r2);
        }
    }

    public static LottieTask<LottieComposition> fromRawRes(Context context, int i) {
        return cache(rawResCacheKey(i), new Callable<LottieResult<LottieComposition>>() { // from class: com.airbnb.lottie.LottieCompositionFactory.2
            final /* synthetic */ Context val$appContext;
            final /* synthetic */ int val$rawRes;

            AnonymousClass2(Context context2, int i2) {
                r1 = context2;
                r2 = i2;
            }

            @Override // java.util.concurrent.Callable
            public LottieResult<LottieComposition> call() {
                return LottieCompositionFactory.fromRawResSync(r1, r2);
            }
        });
    }

    public static LottieResult<LottieComposition> fromRawResSync(Context context, int i) {
        try {
            return fromJsonInputStreamSync(context.getResources().openRawResource(i), rawResCacheKey(i));
        } catch (Resources.NotFoundException e) {
            return new LottieResult<>((Throwable) e);
        }
    }

    private static String rawResCacheKey(int i) {
        return "rawRes_" + i;
    }

    /* renamed from: com.airbnb.lottie.LottieCompositionFactory$3 */
    class AnonymousClass3 implements Callable<LottieResult<LottieComposition>> {
        final /* synthetic */ String val$cacheKey;
        final /* synthetic */ InputStream val$stream;

        AnonymousClass3(InputStream inputStream, String str) {
            r1 = inputStream;
            r2 = str;
        }

        @Override // java.util.concurrent.Callable
        public LottieResult<LottieComposition> call() {
            return LottieCompositionFactory.fromJsonInputStreamSync(r1, r2);
        }
    }

    public static LottieTask<LottieComposition> fromJsonInputStream(InputStream inputStream, String str) {
        return cache(str, new Callable<LottieResult<LottieComposition>>() { // from class: com.airbnb.lottie.LottieCompositionFactory.3
            final /* synthetic */ String val$cacheKey;
            final /* synthetic */ InputStream val$stream;

            AnonymousClass3(InputStream inputStream2, String str2) {
                r1 = inputStream2;
                r2 = str2;
            }

            @Override // java.util.concurrent.Callable
            public LottieResult<LottieComposition> call() {
                return LottieCompositionFactory.fromJsonInputStreamSync(r1, r2);
            }
        });
    }

    public static LottieResult<LottieComposition> fromJsonInputStreamSync(InputStream inputStream, String str) {
        return fromJsonInputStreamSync(inputStream, str, true);
    }

    private static LottieResult<LottieComposition> fromJsonInputStreamSync(InputStream inputStream, String str, boolean z) {
        try {
            return fromJsonReaderSync(new JsonReader(new InputStreamReader(inputStream)), str);
        } finally {
            if (z) {
                Utils.closeQuietly(inputStream);
            }
        }
    }

    /* renamed from: com.airbnb.lottie.LottieCompositionFactory$4 */
    class AnonymousClass4 implements Callable<LottieResult<LottieComposition>> {
        final /* synthetic */ String val$cacheKey;
        final /* synthetic */ JSONObject val$json;

        AnonymousClass4(JSONObject jSONObject, String str) {
            r1 = jSONObject;
            r2 = str;
        }

        @Override // java.util.concurrent.Callable
        public LottieResult<LottieComposition> call() {
            return LottieCompositionFactory.fromJsonSync(r1, r2);
        }
    }

    @Deprecated
    public static LottieTask<LottieComposition> fromJson(JSONObject jSONObject, String str) {
        return cache(str, new Callable<LottieResult<LottieComposition>>() { // from class: com.airbnb.lottie.LottieCompositionFactory.4
            final /* synthetic */ String val$cacheKey;
            final /* synthetic */ JSONObject val$json;

            AnonymousClass4(JSONObject jSONObject2, String str2) {
                r1 = jSONObject2;
                r2 = str2;
            }

            @Override // java.util.concurrent.Callable
            public LottieResult<LottieComposition> call() {
                return LottieCompositionFactory.fromJsonSync(r1, r2);
            }
        });
    }

    @Deprecated
    public static LottieResult<LottieComposition> fromJsonSync(JSONObject jSONObject, String str) {
        return fromJsonStringSync(jSONObject.toString(), str);
    }

    /* renamed from: com.airbnb.lottie.LottieCompositionFactory$5 */
    class AnonymousClass5 implements Callable<LottieResult<LottieComposition>> {
        final /* synthetic */ String val$cacheKey;
        final /* synthetic */ String val$json;

        AnonymousClass5(String str, String str2) {
            r1 = str;
            r2 = str2;
        }

        @Override // java.util.concurrent.Callable
        public LottieResult<LottieComposition> call() {
            return LottieCompositionFactory.fromJsonStringSync(r1, r2);
        }
    }

    public static LottieTask<LottieComposition> fromJsonString(String str, String str2) {
        return cache(str2, new Callable<LottieResult<LottieComposition>>() { // from class: com.airbnb.lottie.LottieCompositionFactory.5
            final /* synthetic */ String val$cacheKey;
            final /* synthetic */ String val$json;

            AnonymousClass5(String str3, String str22) {
                r1 = str3;
                r2 = str22;
            }

            @Override // java.util.concurrent.Callable
            public LottieResult<LottieComposition> call() {
                return LottieCompositionFactory.fromJsonStringSync(r1, r2);
            }
        });
    }

    public static LottieResult<LottieComposition> fromJsonStringSync(String str, String str2) {
        return fromJsonReaderSync(new JsonReader(new StringReader(str)), str2);
    }

    /* renamed from: com.airbnb.lottie.LottieCompositionFactory$6 */
    class AnonymousClass6 implements Callable<LottieResult<LottieComposition>> {
        final /* synthetic */ String val$cacheKey;
        final /* synthetic */ JsonReader val$reader;

        AnonymousClass6(JsonReader jsonReader, String str) {
            r1 = jsonReader;
            r2 = str;
        }

        @Override // java.util.concurrent.Callable
        public LottieResult<LottieComposition> call() {
            return LottieCompositionFactory.fromJsonReaderSync(r1, r2);
        }
    }

    public static LottieTask<LottieComposition> fromJsonReader(JsonReader jsonReader, String str) {
        return cache(str, new Callable<LottieResult<LottieComposition>>() { // from class: com.airbnb.lottie.LottieCompositionFactory.6
            final /* synthetic */ String val$cacheKey;
            final /* synthetic */ JsonReader val$reader;

            AnonymousClass6(JsonReader jsonReader2, String str2) {
                r1 = jsonReader2;
                r2 = str2;
            }

            @Override // java.util.concurrent.Callable
            public LottieResult<LottieComposition> call() {
                return LottieCompositionFactory.fromJsonReaderSync(r1, r2);
            }
        });
    }

    public static LottieResult<LottieComposition> fromJsonReaderSync(JsonReader jsonReader, String str) {
        try {
            LottieComposition parse = LottieCompositionParser.parse(jsonReader);
            LottieCompositionCache.getInstance().put(str, parse);
            return new LottieResult<>(parse);
        } catch (Exception e) {
            return new LottieResult<>((Throwable) e);
        }
    }

    /* renamed from: com.airbnb.lottie.LottieCompositionFactory$7 */
    class AnonymousClass7 implements Callable<LottieResult<LottieComposition>> {
        final /* synthetic */ String val$cacheKey;
        final /* synthetic */ ZipInputStream val$inputStream;

        AnonymousClass7(ZipInputStream zipInputStream, String str) {
            r1 = zipInputStream;
            r2 = str;
        }

        @Override // java.util.concurrent.Callable
        public LottieResult<LottieComposition> call() {
            return LottieCompositionFactory.fromZipStreamSync(r1, r2);
        }
    }

    public static LottieTask<LottieComposition> fromZipStream(ZipInputStream zipInputStream, String str) {
        return cache(str, new Callable<LottieResult<LottieComposition>>() { // from class: com.airbnb.lottie.LottieCompositionFactory.7
            final /* synthetic */ String val$cacheKey;
            final /* synthetic */ ZipInputStream val$inputStream;

            AnonymousClass7(ZipInputStream zipInputStream2, String str2) {
                r1 = zipInputStream2;
                r2 = str2;
            }

            @Override // java.util.concurrent.Callable
            public LottieResult<LottieComposition> call() {
                return LottieCompositionFactory.fromZipStreamSync(r1, r2);
            }
        });
    }

    public static LottieResult<LottieComposition> fromZipStreamSync(ZipInputStream zipInputStream, String str) {
        try {
            return fromZipStreamSyncInternal(zipInputStream, str);
        } finally {
            Utils.closeQuietly(zipInputStream);
        }
    }

    private static LottieResult<LottieComposition> fromZipStreamSyncInternal(ZipInputStream zipInputStream, String str) {
        HashMap hashMap = new HashMap();
        try {
            ZipEntry nextEntry = zipInputStream.getNextEntry();
            LottieComposition lottieComposition = null;
            while (nextEntry != null) {
                if (nextEntry.getName().contains("__MACOSX")) {
                    zipInputStream.closeEntry();
                } else if (nextEntry.getName().contains(".json")) {
                    lottieComposition = fromJsonInputStreamSync(zipInputStream, str, false).getValue();
                } else if (nextEntry.getName().contains(".png")) {
                    hashMap.put(nextEntry.getName().split("/")[r1.length - 1], BitmapFactory.decodeStream(zipInputStream));
                } else {
                    zipInputStream.closeEntry();
                }
                nextEntry = zipInputStream.getNextEntry();
            }
            if (lottieComposition == null) {
                return new LottieResult<>((Throwable) new IllegalArgumentException("Unable to parse composition"));
            }
            for (Map.Entry entry : hashMap.entrySet()) {
                LottieImageAsset findImageAssetForFileName = findImageAssetForFileName(lottieComposition, (String) entry.getKey());
                if (findImageAssetForFileName != null) {
                    findImageAssetForFileName.setBitmap((Bitmap) entry.getValue());
                }
            }
            for (Map.Entry<String, LottieImageAsset> entry2 : lottieComposition.getImages().entrySet()) {
                if (entry2.getValue().getBitmap() == null) {
                    return new LottieResult<>((Throwable) new IllegalStateException("There is no image for " + entry2.getValue().getFileName()));
                }
            }
            LottieCompositionCache.getInstance().put(str, lottieComposition);
            return new LottieResult<>(lottieComposition);
        } catch (IOException e) {
            return new LottieResult<>((Throwable) e);
        }
    }

    private static LottieImageAsset findImageAssetForFileName(LottieComposition lottieComposition, String str) {
        for (LottieImageAsset lottieImageAsset : lottieComposition.getImages().values()) {
            if (lottieImageAsset.getFileName().equals(str)) {
                return lottieImageAsset;
            }
        }
        return null;
    }

    private static LottieTask<LottieComposition> cache(String str, Callable<LottieResult<LottieComposition>> callable) {
        LottieComposition lottieComposition = LottieCompositionCache.getInstance().get(str);
        if (lottieComposition != null) {
            return new LottieTask<>(new Callable<LottieResult<LottieComposition>>() { // from class: com.airbnb.lottie.LottieCompositionFactory.8
                AnonymousClass8() {
                }

                @Override // java.util.concurrent.Callable
                public LottieResult<LottieComposition> call() {
                    Log.d("Gabe", "call\treturning from cache");
                    return new LottieResult<>(LottieComposition.this);
                }
            });
        }
        Map<String, LottieTask<LottieComposition>> map = taskCache;
        if (map.containsKey(str)) {
            return map.get(str);
        }
        LottieTask<LottieComposition> lottieTask = new LottieTask<>(callable);
        lottieTask.addListener(new LottieListener<LottieComposition>() { // from class: com.airbnb.lottie.LottieCompositionFactory.9
            final /* synthetic */ String val$cacheKey;

            AnonymousClass9(String str2) {
                r1 = str2;
            }

            @Override // com.airbnb.lottie.LottieListener
            public void onResult(LottieComposition lottieComposition2) {
                if (r1 != null) {
                    LottieCompositionCache.getInstance().put(r1, lottieComposition2);
                }
                LottieCompositionFactory.taskCache.remove(r1);
            }
        });
        lottieTask.addFailureListener(new LottieListener<Throwable>() { // from class: com.airbnb.lottie.LottieCompositionFactory.10
            final /* synthetic */ String val$cacheKey;

            AnonymousClass10(String str2) {
                r1 = str2;
            }

            @Override // com.airbnb.lottie.LottieListener
            public void onResult(Throwable th) {
                LottieCompositionFactory.taskCache.remove(r1);
            }
        });
        map.put(str2, lottieTask);
        return lottieTask;
    }

    /* renamed from: com.airbnb.lottie.LottieCompositionFactory$8 */
    class AnonymousClass8 implements Callable<LottieResult<LottieComposition>> {
        AnonymousClass8() {
        }

        @Override // java.util.concurrent.Callable
        public LottieResult<LottieComposition> call() {
            Log.d("Gabe", "call\treturning from cache");
            return new LottieResult<>(LottieComposition.this);
        }
    }

    /* renamed from: com.airbnb.lottie.LottieCompositionFactory$9 */
    class AnonymousClass9 implements LottieListener<LottieComposition> {
        final /* synthetic */ String val$cacheKey;

        AnonymousClass9(String str2) {
            r1 = str2;
        }

        @Override // com.airbnb.lottie.LottieListener
        public void onResult(LottieComposition lottieComposition2) {
            if (r1 != null) {
                LottieCompositionCache.getInstance().put(r1, lottieComposition2);
            }
            LottieCompositionFactory.taskCache.remove(r1);
        }
    }

    /* renamed from: com.airbnb.lottie.LottieCompositionFactory$10 */
    class AnonymousClass10 implements LottieListener<Throwable> {
        final /* synthetic */ String val$cacheKey;

        AnonymousClass10(String str2) {
            r1 = str2;
        }

        @Override // com.airbnb.lottie.LottieListener
        public void onResult(Throwable th) {
            LottieCompositionFactory.taskCache.remove(r1);
        }
    }
}
