package com.bea.xml.stream;

import java.util.Enumeration;
import java.util.HashSet;
import java.util.Hashtable;
import javax.xml.stream.XMLReporter;
import javax.xml.stream.XMLResolver;
import javax.xml.stream.util.XMLEventAllocator;

/* loaded from: classes.dex */
public class ConfigurationContextBase {
    private static String ENTITIES = "javax.xml.stream.entities";
    private static String EVENT_FILTER = "RI_EVENT_FILTER";
    private static String NOTATIONS = "javax.xml.stream.notations";
    static final String REPORT_CDATA = "http://java.sun.com/xml/stream/properties/report-cdata-event";
    private static String STREAM_FILTER = "RI_STREAM_FILTER";
    private static HashSet supportedFeatures;
    private Hashtable features;

    public String getVersion() {
        return "1.0";
    }

    static {
        HashSet hashSet = new HashSet();
        supportedFeatures = hashSet;
        hashSet.add("javax.xml.stream.isValidating");
        supportedFeatures.add("javax.xml.stream.isCoalescing");
        supportedFeatures.add("javax.xml.stream.isReplacingEntityReferences");
        supportedFeatures.add("javax.xml.stream.isSupportingExternalEntities");
        supportedFeatures.add("javax.xml.stream.isRepairingNamespaces");
        supportedFeatures.add("javax.xml.stream.isNamespaceAware");
        supportedFeatures.add("javax.xml.stream.supportDTD");
        supportedFeatures.add("javax.xml.stream.reporter");
        supportedFeatures.add("javax.xml.stream.resolver");
        supportedFeatures.add("javax.xml.stream.allocator");
        supportedFeatures.add(NOTATIONS);
        supportedFeatures.add(ENTITIES);
        supportedFeatures.add(REPORT_CDATA);
    }

    public ConfigurationContextBase() {
        Hashtable hashtable = new Hashtable();
        this.features = hashtable;
        hashtable.put("javax.xml.stream.isValidating", Boolean.FALSE);
        this.features.put("javax.xml.stream.isCoalescing", Boolean.FALSE);
        this.features.put("javax.xml.stream.isReplacingEntityReferences", Boolean.TRUE);
        this.features.put("javax.xml.stream.isSupportingExternalEntities", Boolean.FALSE);
        this.features.put("javax.xml.stream.isNamespaceAware", Boolean.TRUE);
        this.features.put("javax.xml.stream.supportDTD", Boolean.FALSE);
        this.features.put("javax.xml.stream.isRepairingNamespaces", Boolean.FALSE);
    }

    public void setEventAllocator(XMLEventAllocator xMLEventAllocator) {
        this.features.put("javax.xml.stream.allocator", xMLEventAllocator);
    }

    public XMLEventAllocator getEventAllocator() {
        return (XMLEventAllocator) this.features.get("javax.xml.stream.allocator");
    }

    public void setProperty(String str, Object obj) {
        if (str.equals("javax.xml.stream.isValidating")) {
            setValidating(((Boolean) obj).booleanValue());
            return;
        }
        if (str.equals("javax.xml.stream.isSupportingExternalEntities")) {
            setSupportExternalEntities(((Boolean) obj).booleanValue());
        } else if (str.equals("javax.xml.stream.isNamespaceAware")) {
            setNamespaceAware(((Boolean) obj).booleanValue());
        } else {
            check(str);
            this.features.put(str, obj);
        }
    }

    public void check(String str) {
        if (supportedFeatures.contains(str)) {
            return;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unable to access unsupported property ");
        stringBuffer.append(str);
        throw new IllegalArgumentException(stringBuffer.toString());
    }

    public Object getProperty(String str) {
        check(str);
        return this.features.get(str);
    }

    public void setXMLReporter(XMLReporter xMLReporter) {
        this.features.put("javax.xml.stream.reporter", xMLReporter);
    }

    public XMLReporter getXMLReporter() {
        return (XMLReporter) this.features.get("javax.xml.stream.reporter");
    }

    public void setXMLResolver(XMLResolver xMLResolver) {
        this.features.put("javax.xml.stream.resolver", xMLResolver);
    }

    public XMLResolver getXMLResolver() {
        return (XMLResolver) this.features.get("javax.xml.stream.resolver");
    }

    public boolean getBool(String str) {
        check(str);
        return ((Boolean) this.features.get(str)).booleanValue();
    }

    public void setBool(String str, boolean z) {
        check(str);
        this.features.put(str, z ? Boolean.TRUE : Boolean.FALSE);
    }

    public void setCoalescing(boolean z) {
        setBool("javax.xml.stream.isCoalescing", z);
    }

    public boolean isCoalescing() {
        return getBool("javax.xml.stream.isCoalescing");
    }

    public void setValidating(boolean z) {
        if (z) {
            throw new IllegalArgumentException("This implementation does not support validation");
        }
    }

    public boolean isValidating() {
        return getBool("javax.xml.stream.isValidating");
    }

    public void setReplacingEntities(boolean z) {
        setBool("javax.xml.stream.isReplacingEntityReferences", z);
    }

    public boolean isReplacingEntities() {
        return getBool("javax.xml.stream.isReplacingEntityReferences");
    }

    public void setSupportExternalEntities(boolean z) {
        if (z) {
            throw new IllegalArgumentException("This implementation does not resolve external entities ");
        }
    }

    public boolean isSupportingExternalEntities() {
        return getBool("javax.xml.stream.isSupportingExternalEntities");
    }

    public void setPrefixDefaulting(boolean z) {
        setBool("javax.xml.stream.isRepairingNamespaces", z);
    }

    public boolean isPrefixDefaulting() {
        return getBool("javax.xml.stream.isRepairingNamespaces");
    }

    public void setNamespaceAware(boolean z) {
        if (!z) {
            throw new IllegalArgumentException("This implementation does not allow disabling namespace processing");
        }
    }

    public boolean isNamespaceAware() {
        return getBool("javax.xml.stream.isNamespaceAware");
    }

    public Enumeration getProperties() {
        return this.features.keys();
    }

    public boolean isPropertySupported(String str) {
        return supportedFeatures.contains(str);
    }
}
