package com.bea.xml.stream;

import com.bea.xml.stream.util.ElementTypeNames;
import com.dd.plist.ASCIIPropertyListParser;
import com.facebook.share.internal.MessengerShareContentUtility;
import java.io.FileReader;
import java.io.IOException;
import java.io.Reader;
import java.util.ArrayList;
import java.util.List;
import javax.xml.namespace.QName;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.events.Attribute;
import javax.xml.stream.events.Namespace;

/* loaded from: classes.dex */
public class EventScanner {
    protected char currentChar;
    protected int currentLine = 0;
    private boolean readEndDocument = false;
    protected Reader reader;

    public EventScanner() {
    }

    public EventScanner(Reader reader) throws IOException {
        setReader(reader);
    }

    public void setReader(Reader reader) throws IOException {
        this.reader = reader;
        read();
        skipSpace();
    }

    protected String readString(char c) throws IOException, XMLStreamException {
        StringBuffer stringBuffer = new StringBuffer();
        while (getChar() != c) {
            if (getChar() == '[' && c == ']') {
                read();
                stringBuffer.append('[');
                if (getChar() != ']') {
                    stringBuffer.append(readString(']'));
                }
                stringBuffer.append(']');
                read(']');
            } else {
                stringBuffer.append(getChar());
                read();
            }
        }
        return stringBuffer.toString();
    }

    protected char getChar() {
        return this.currentChar;
    }

    protected void skipSpace() throws IOException {
        while (true) {
            char c = this.currentChar;
            if (!((c == ' ') | (c == '\n') | (c == '\t')) && !(c == '\r')) {
                return;
            } else {
                read();
            }
        }
    }

    protected char read() throws IOException {
        char read = (char) this.reader.read();
        this.currentChar = read;
        if (read == '\n') {
            this.currentLine++;
        }
        return read;
    }

    protected char read(char c) throws XMLStreamException, IOException {
        if (this.currentChar == c) {
            return read();
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unexpected character '");
        stringBuffer.append(this.currentChar);
        stringBuffer.append("' , expected '");
        stringBuffer.append(c);
        stringBuffer.append("' at line ");
        stringBuffer.append(this.currentLine);
        throw new XMLStreamException(stringBuffer.toString());
    }

    protected void read(String str) throws XMLStreamException, IOException {
        for (int i = 0; i < str.length(); i++) {
            read(str.charAt(i));
        }
    }

    protected int readType() throws XMLStreamException, IOException {
        read('[');
        int eventType = ElementTypeNames.getEventType(readString(']'));
        read(']');
        return eventType;
    }

    public EventState readStartElement() throws XMLStreamException, IOException {
        EventState eventState = new EventState(1);
        read('[');
        eventState.setName(readName());
        if (getChar() == '[') {
            for (Object obj : readAttributes()) {
                if (obj instanceof Namespace) {
                    eventState.addNamespace(obj);
                } else {
                    eventState.addAttribute(obj);
                }
            }
        }
        read(']');
        return eventState;
    }

    public EventState readEndElement() throws XMLStreamException, IOException {
        EventState eventState = new EventState(2);
        read('[');
        eventState.setName(readName());
        read(']');
        return eventState;
    }

    public EventState readProcessingInstruction() throws XMLStreamException, IOException {
        String str;
        EventState eventState = new EventState(3);
        read('[');
        String readString = readString(']');
        read(']');
        if (getChar() == ',') {
            read(",[");
            str = readString(']');
            read(']');
        } else {
            str = null;
        }
        eventState.setData(readString);
        eventState.setExtraData(str);
        return eventState;
    }

    public EventState readCharacterData() throws XMLStreamException, IOException {
        EventState eventState = new EventState(4);
        read('[');
        eventState.setData(readString(']'));
        read(']');
        return eventState;
    }

    public EventState readCDATA() throws XMLStreamException, IOException {
        EventState eventState = new EventState(12);
        read('[');
        readString(']');
        read(']');
        return eventState;
    }

    public EventState readStartDocument() throws XMLStreamException, IOException {
        EventState eventState = new EventState(7);
        if (getChar() != ';') {
            read('[');
            read('[');
            String readString = readString(']');
            read(']');
            read(ASCIIPropertyListParser.ARRAY_ITEM_DELIMITER_TOKEN);
            read('[');
            String readString2 = readString(']');
            read(']');
            read(']');
            eventState.setData(readString);
            eventState.setExtraData(readString2);
        }
        return eventState;
    }

    public EventState readDTD() throws XMLStreamException, IOException {
        EventState eventState = new EventState(11);
        read('[');
        String readString = readString(']');
        read(']');
        eventState.setData(readString);
        return eventState;
    }

    public EventState readEndDocument() throws XMLStreamException {
        return new EventState(8);
    }

    public EventState readComment() throws XMLStreamException, IOException {
        EventState eventState = new EventState(5);
        read('[');
        eventState.setData(readString(']'));
        read(']');
        return eventState;
    }

    public String getPrefix(String str) {
        int indexOf = str.indexOf(58);
        if (indexOf == -1) {
            return null;
        }
        return str.substring(0, indexOf);
    }

    public String getName(String str) {
        int indexOf = str.indexOf(58);
        return indexOf == -1 ? str : str.substring(indexOf + 1);
    }

    public QName readName() throws XMLStreamException, IOException {
        read('[');
        QName readName = readName(']');
        read(']');
        return readName;
    }

    public QName readName(char c) throws XMLStreamException, IOException {
        String str;
        if (getChar() == '\'') {
            read('\'');
            str = readString('\'');
            read('\'');
            read(ASCIIPropertyListParser.DATE_TIME_FIELD_DELIMITER);
        } else {
            str = "";
        }
        String readString = readString(c);
        String prefix = getPrefix(readString);
        return new QName(str, getName(readString), prefix != null ? prefix : "");
    }

    public List readAttributes() throws XMLStreamException, IOException {
        ArrayList arrayList = new ArrayList();
        while (getChar() == '[') {
            arrayList.add(readAttribute());
        }
        return arrayList;
    }

    public Attribute readAttribute() throws XMLStreamException, IOException {
        read('[');
        read('[');
        String readString = readString(']');
        read(']');
        QName readName = readName();
        read("=[");
        String readString2 = readString(']');
        read(']');
        read(']');
        if (readString.equals("ATTRIBUTE")) {
            return new AttributeBase(readName, readString2);
        }
        if (readString.equals(MessengerShareContentUtility.PREVIEW_DEFAULT)) {
            return new NamespaceBase(readString2);
        }
        if (readString.equals("NAMESPACE")) {
            return new NamespaceBase(readName.getLocalPart(), readString2);
        }
        throw new XMLStreamException("Parser Error expected (ATTRIBUTE||DEFAULT|NAMESPACE");
    }

    public EventState readEntityReference() throws XMLStreamException, IOException {
        EventState eventState = new EventState(9);
        read('[');
        eventState.setData(readString(']'));
        read(']');
        return eventState;
    }

    public EventState readSpace() throws XMLStreamException, IOException {
        EventState eventState = new EventState(6);
        read('[');
        String readString = readString(']');
        read(']');
        eventState.setData(readString);
        return eventState;
    }

    public EventState readElement() throws XMLStreamException, IOException {
        EventState readStartElement;
        int readType = readType();
        switch (readType) {
            case 1:
                readStartElement = readStartElement();
                break;
            case 2:
                readStartElement = readEndElement();
                break;
            case 3:
                readStartElement = readProcessingInstruction();
                break;
            case 4:
                readStartElement = readCharacterData();
                break;
            case 5:
                readStartElement = readComment();
                break;
            case 6:
                readStartElement = readSpace();
                break;
            case 7:
                readStartElement = readStartDocument();
                break;
            case 8:
                this.readEndDocument = true;
                readStartElement = readEndDocument();
                break;
            case 9:
                readStartElement = readEntityReference();
                break;
            case 10:
            default:
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Attempt to read unknown element [");
                stringBuffer.append(readType);
                stringBuffer.append("]");
                throw new XMLStreamException(stringBuffer.toString());
            case 11:
                readStartElement = readDTD();
                break;
            case 12:
                readStartElement = readCDATA();
                break;
        }
        read(ASCIIPropertyListParser.DICTIONARY_ITEM_DELIMITER_TOKEN);
        skipSpace();
        return readStartElement;
    }

    public boolean endDocumentIsPresent() {
        return this.readEndDocument;
    }

    public boolean hasNext() throws IOException {
        return this.reader.ready() && !this.readEndDocument;
    }

    public static void main(String[] strArr) throws Exception {
        EventScanner eventScanner = new EventScanner(new FileReader(strArr[0]));
        while (eventScanner.hasNext()) {
            System.out.println(eventScanner.readElement());
        }
    }
}
