package com.bea.xml.stream;

import com.bea.xml.stream.util.NamespaceContextImpl;
import java.io.FileReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import javax.xml.namespace.NamespaceContext;
import javax.xml.namespace.QName;
import javax.xml.stream.Location;
import javax.xml.stream.XMLOutputFactory;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.XMLStreamWriter;
import javax.xml.stream.events.Attribute;

/* loaded from: classes.dex */
public class XMLStreamPlayer implements XMLStreamReader {
    NamespaceContextImpl context = new NamespaceContextImpl();
    EventScanner scanner;
    EventState state;

    public void close() throws XMLStreamException {
    }

    public String getAttributeType(int i) {
        return "CDATA";
    }

    public String getCharacterEncodingScheme() {
        return null;
    }

    public Location getLocation() {
        return null;
    }

    public Object getProperty(String str) throws IllegalArgumentException {
        return null;
    }

    public int getTextStart() {
        return 0;
    }

    public String getVersion() {
        return "1.0";
    }

    public boolean isAttributeSpecified(int i) {
        return false;
    }

    public boolean isStandalone() {
        return true;
    }

    public boolean isWhiteSpace() {
        return false;
    }

    public void require(int i, String str, String str2) throws XMLStreamException {
    }

    public boolean standaloneSet() {
        return false;
    }

    public XMLStreamReader subReader() throws XMLStreamException {
        return null;
    }

    public XMLStreamPlayer() {
    }

    public XMLStreamPlayer(InputStream inputStream) {
        try {
            this.scanner = new EventScanner(new InputStreamReader(inputStream));
            next();
            if (getEventType() == 7) {
                this.scanner = new EventScanner(new InputStreamReader(inputStream, getCharacterEncodingScheme()));
            }
        } catch (Exception e) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Unable to instantiate the XMLStreamPlayer");
            stringBuffer.append(e.getMessage());
            throw new IllegalArgumentException(stringBuffer.toString());
        }
    }

    public XMLStreamPlayer(Reader reader) {
        try {
            this.scanner = new EventScanner(reader);
            next();
        } catch (Exception e) {
            System.out.println(e);
        }
    }

    public int next() throws XMLStreamException {
        try {
            if (!this.scanner.hasNext()) {
                this.state = null;
                return -1;
            }
            this.state = this.scanner.readElement();
            if (isStartElement()) {
                this.context.openScope();
                for (int i = 0; i < getNamespaceCount(); i++) {
                    this.context.bindNamespace(getNamespacePrefix(i), getNamespaceURI(i));
                }
            } else if (isEndElement() && this.context.getDepth() > 0) {
                this.context.closeScope();
            }
            return this.state.getType();
        } catch (Exception e) {
            System.out.println(e);
            e.printStackTrace();
            throw new XMLStreamException(e.getMessage(), e);
        }
    }

    public String getElementText() throws XMLStreamException {
        StringBuffer stringBuffer = new StringBuffer();
        if (getEventType() != 1) {
            throw new XMLStreamException("Precondition for readText is getEventType() == START_ELEMENT");
        }
        while (next() != 8) {
            if (isStartElement()) {
                throw new XMLStreamException("Unexpected Element start");
            }
            if (isCharacters()) {
                stringBuffer.append(getText());
            }
            if (isEndElement()) {
                return stringBuffer.toString();
            }
        }
        throw new XMLStreamException("Unexpected end of Document");
    }

    public int nextTag() throws XMLStreamException {
        while (next() != 8) {
            if (isCharacters() && !isWhiteSpace()) {
                throw new XMLStreamException("Unexpected text");
            }
            if (isStartElement() || isEndElement()) {
                return getEventType();
            }
        }
        throw new XMLStreamException("Unexpected end of Document");
    }

    public boolean hasNext() throws XMLStreamException {
        try {
            EventState eventState = this.state;
            if (eventState != null) {
                if (eventState.getType() != 8) {
                    return true;
                }
            }
            return false;
        } catch (Exception e) {
            throw new XMLStreamException(e);
        }
    }

    public String getNamespaceURI(String str) {
        return this.context.getNamespaceURI(str);
    }

    private Attribute getAttributeInternal(int i) {
        return (Attribute) this.state.getAttributes().get(i);
    }

    private Attribute getNamespaceInternal(int i) {
        return (Attribute) this.state.getNamespaces().get(i);
    }

    public boolean isStartElement() {
        return (getEventType() & 1) != 0;
    }

    public boolean isEndElement() {
        return (getEventType() & 2) != 0;
    }

    public boolean isCharacters() {
        return (getEventType() & 4) != 0;
    }

    public String getAttributeValue(String str, String str2) {
        for (int i = 0; i < getAttributeCount(); i++) {
            Attribute attributeInternal = getAttributeInternal(i);
            if (str2.equals(attributeInternal.getName().getLocalPart())) {
                if (str == null) {
                    return attributeInternal.getValue();
                }
                if (str.equals(attributeInternal.getName().getNamespaceURI())) {
                    return attributeInternal.getValue();
                }
            }
        }
        return null;
    }

    public int getAttributeCount() {
        if (isStartElement()) {
            return this.state.getAttributes().size();
        }
        return 0;
    }

    public QName getAttributeName(int i) {
        return new QName(getAttributeNamespace(i), getAttributeLocalName(i), getAttributePrefix(i));
    }

    public String getAttributeNamespace(int i) {
        Attribute attributeInternal = getAttributeInternal(i);
        if (attributeInternal == null) {
            return null;
        }
        return attributeInternal.getName().getNamespaceURI();
    }

    public String getAttributeLocalName(int i) {
        Attribute attributeInternal = getAttributeInternal(i);
        if (attributeInternal == null) {
            return null;
        }
        return attributeInternal.getName().getLocalPart();
    }

    public String getAttributePrefix(int i) {
        Attribute attributeInternal = getAttributeInternal(i);
        if (attributeInternal == null) {
            return null;
        }
        return attributeInternal.getName().getPrefix();
    }

    public String getAttributeValue(int i) {
        Attribute attributeInternal = getAttributeInternal(i);
        if (attributeInternal == null) {
            return null;
        }
        return attributeInternal.getValue();
    }

    public int getNamespaceCount() {
        if (isStartElement()) {
            return this.state.getNamespaces().size();
        }
        return 0;
    }

    public String getNamespacePrefix(int i) {
        Attribute namespaceInternal = getNamespaceInternal(i);
        if (namespaceInternal == null) {
            return null;
        }
        return namespaceInternal.getName().getLocalPart();
    }

    public String getNamespaceURI(int i) {
        Attribute namespaceInternal = getNamespaceInternal(i);
        if (namespaceInternal == null) {
            return null;
        }
        return namespaceInternal.getValue();
    }

    public NamespaceContext getNamespaceContext() {
        return this.context;
    }

    public int getEventType() {
        EventState eventState = this.state;
        if (eventState == null) {
            return 8;
        }
        return eventState.getType();
    }

    public String getText() {
        return this.state.getData();
    }

    public Reader getTextStream() {
        throw new UnsupportedOperationException();
    }

    public char[] getTextCharacters() {
        return this.state.getData().toCharArray();
    }

    public int getTextCharacters(int i, char[] cArr, int i2, int i3) throws XMLStreamException {
        throw new UnsupportedOperationException();
    }

    public int getTextLength() {
        return this.state.getData().length();
    }

    public String getEncoding() {
        return this.state.getData();
    }

    public boolean hasText() {
        return (getEventType() & 15) != 0;
    }

    public QName getName() {
        return new QName(getNamespaceURI(), getLocalName(), getPrefix());
    }

    public String getLocalName() {
        return this.state.getLocalName();
    }

    public boolean hasName() {
        return (getEventType() & 11) != 0;
    }

    public String getNamespaceURI() {
        return this.state.getNamespaceURI();
    }

    public String getPrefix() {
        return this.state.getPrefix();
    }

    public String getPITarget() {
        return this.state.getData();
    }

    public String getPIData() {
        return this.state.getExtraData();
    }

    public boolean endDocumentIsPresent() {
        return this.scanner.endDocumentIsPresent();
    }

    public static void main(String[] strArr) throws Exception {
        XMLStreamPlayer xMLStreamPlayer = new XMLStreamPlayer(new FileReader(strArr[0]));
        XMLStreamWriter createXMLStreamWriter = XMLOutputFactory.newInstance().createXMLStreamWriter(System.out);
        ReaderToWriter readerToWriter = new ReaderToWriter(createXMLStreamWriter);
        while (xMLStreamPlayer.hasNext()) {
            readerToWriter.write(xMLStreamPlayer);
            xMLStreamPlayer.next();
        }
        createXMLStreamWriter.flush();
    }
}
