package com.dd.plist;

import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.nio.ByteBuffer;
import java.util.Arrays;
import kotlin.UByte;

/* loaded from: classes.dex */
public class NSData extends NSObject {
    private byte[] bytes;

    public NSData(byte[] bArr) {
        this.bytes = bArr;
    }

    public NSData(String str) throws IOException {
        this.bytes = Base64.decode(str.replaceAll("\\s+", ""));
    }

    public NSData(File file) throws IOException {
        this.bytes = new byte[(int) file.length()];
        RandomAccessFile randomAccessFile = new RandomAccessFile(file, "r");
        randomAccessFile.read(this.bytes);
        randomAccessFile.close();
    }

    public byte[] bytes() {
        return this.bytes;
    }

    public int length() {
        return this.bytes.length;
    }

    public void getBytes(ByteBuffer byteBuffer, int i) {
        byte[] bArr = this.bytes;
        byteBuffer.put(bArr, 0, Math.min(bArr.length, i));
    }

    public void getBytes(ByteBuffer byteBuffer, int i, int i2) {
        byte[] bArr = this.bytes;
        byteBuffer.put(bArr, i, Math.min(bArr.length, i2));
    }

    public String getBase64EncodedData() {
        return Base64.encodeBytes(this.bytes);
    }

    public boolean equals(Object obj) {
        return obj.getClass().equals(getClass()) && Arrays.equals(((NSData) obj).bytes, this.bytes);
    }

    public int hashCode() {
        return 335 + Arrays.hashCode(this.bytes);
    }

    @Override // com.dd.plist.NSObject
    void toXML(StringBuilder sb, int i) {
        indent(sb, i);
        sb.append("<data>");
        sb.append(NSObject.NEWLINE);
        for (String str : getBase64EncodedData().split("\n")) {
            indent(sb, i + 1);
            sb.append(str);
            sb.append(NSObject.NEWLINE);
        }
        indent(sb, i);
        sb.append("</data>");
    }

    @Override // com.dd.plist.NSObject
    void toBinary(BinaryPropertyListWriter binaryPropertyListWriter) throws IOException {
        binaryPropertyListWriter.writeIntHeader(4, this.bytes.length);
        binaryPropertyListWriter.write(this.bytes);
    }

    @Override // com.dd.plist.NSObject
    protected void toASCII(StringBuilder sb, int i) {
        indent(sb, i);
        sb.append('<');
        int lastIndexOf = sb.lastIndexOf(NEWLINE);
        int i2 = 0;
        while (true) {
            byte[] bArr = this.bytes;
            if (i2 < bArr.length) {
                int i3 = bArr[i2] & UByte.MAX_VALUE;
                if (i3 < 16) {
                    sb.append("0");
                }
                sb.append(Integer.toHexString(i3));
                if (sb.length() - lastIndexOf > 80) {
                    sb.append(NEWLINE);
                    lastIndexOf = sb.length();
                } else if ((i2 + 1) % 2 == 0 && i2 != this.bytes.length - 1) {
                    sb.append(" ");
                }
                i2++;
            } else {
                sb.append('>');
                return;
            }
        }
    }

    @Override // com.dd.plist.NSObject
    protected void toASCIIGnuStep(StringBuilder sb, int i) {
        toASCII(sb, i);
    }
}
