package com.dd.plist;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.nio.ByteBuffer;
import java.nio.CharBuffer;
import java.nio.charset.Charset;
import java.nio.charset.CharsetEncoder;

/* loaded from: classes.dex */
public class NSString extends NSObject implements Comparable<Object> {
    private static CharsetEncoder asciiEncoder;
    private static CharsetEncoder utf16beEncoder;
    private static CharsetEncoder utf8Encoder;
    private String content;

    public NSString(byte[] bArr, String str) throws UnsupportedEncodingException {
        this.content = new String(bArr, str);
    }

    public NSString(String str) {
        this.content = str;
    }

    public String getContent() {
        return this.content;
    }

    public void setContent(String str) {
        this.content = str;
    }

    public void append(NSString nSString) {
        append(nSString.getContent());
    }

    public void append(String str) {
        this.content += str;
    }

    public void prepend(String str) {
        this.content = str + this.content;
    }

    public void prepend(NSString nSString) {
        prepend(nSString.getContent());
    }

    public boolean equals(Object obj) {
        if (obj instanceof NSString) {
            return this.content.equals(((NSString) obj).content);
        }
        return false;
    }

    public int hashCode() {
        return this.content.hashCode();
    }

    public String toString() {
        return this.content;
    }

    @Override // com.dd.plist.NSObject
    void toXML(StringBuilder sb, int i) {
        String str;
        indent(sb, i);
        sb.append("<string>");
        synchronized (NSString.class) {
            CharsetEncoder charsetEncoder = utf8Encoder;
            if (charsetEncoder == null) {
                utf8Encoder = Charset.forName("UTF-8").newEncoder();
            } else {
                charsetEncoder.reset();
            }
            try {
                ByteBuffer encode = utf8Encoder.encode(CharBuffer.wrap(this.content));
                byte[] bArr = new byte[encode.remaining()];
                encode.get(bArr);
                str = new String(bArr, "UTF-8");
                this.content = str;
            } catch (Exception e) {
                throw new RuntimeException("Could not encode the NSString into UTF-8: " + String.valueOf(e.getMessage()));
            }
        }
        if (str.contains("&") || this.content.contains("<") || this.content.contains(">")) {
            sb.append("<![CDATA[");
            sb.append(this.content.replaceAll("]]>", "]]]]><![CDATA[>"));
            sb.append("]]>");
        } else {
            sb.append(this.content);
        }
        sb.append("</string>");
    }

    @Override // com.dd.plist.NSObject
    public void toBinary(BinaryPropertyListWriter binaryPropertyListWriter) throws IOException {
        int i;
        ByteBuffer encode;
        CharBuffer wrap = CharBuffer.wrap(this.content);
        synchronized (NSString.class) {
            CharsetEncoder charsetEncoder = asciiEncoder;
            if (charsetEncoder == null) {
                asciiEncoder = Charset.forName("ASCII").newEncoder();
            } else {
                charsetEncoder.reset();
            }
            if (asciiEncoder.canEncode(wrap)) {
                i = 5;
                encode = asciiEncoder.encode(wrap);
            } else {
                CharsetEncoder charsetEncoder2 = utf16beEncoder;
                if (charsetEncoder2 == null) {
                    utf16beEncoder = Charset.forName("UTF-16BE").newEncoder();
                } else {
                    charsetEncoder2.reset();
                }
                i = 6;
                encode = utf16beEncoder.encode(wrap);
            }
        }
        byte[] bArr = new byte[encode.remaining()];
        encode.get(bArr);
        binaryPropertyListWriter.writeIntHeader(i, this.content.length());
        binaryPropertyListWriter.write(bArr);
    }

    @Override // com.dd.plist.NSObject
    protected void toASCII(StringBuilder sb, int i) {
        indent(sb, i);
        sb.append("\"");
        sb.append(escapeStringForASCII(this.content));
        sb.append("\"");
    }

    @Override // com.dd.plist.NSObject
    protected void toASCIIGnuStep(StringBuilder sb, int i) {
        indent(sb, i);
        sb.append("\"");
        sb.append(escapeStringForASCII(this.content));
        sb.append("\"");
    }

    static String escapeStringForASCII(String str) {
        String str2 = "";
        for (char c : str.toCharArray()) {
            if (c > 127) {
                String str3 = str2 + "\\U";
                String hexString = Integer.toHexString(c);
                while (hexString.length() < 4) {
                    hexString = "0" + hexString;
                }
                str2 = str3 + hexString;
            } else if (c == '\\') {
                str2 = str2 + "\\\\";
            } else if (c == '\"') {
                str2 = str2 + "\\\"";
            } else if (c == '\b') {
                str2 = str2 + "\\b";
            } else if (c == '\n') {
                str2 = str2 + "\\n";
            } else if (c == '\r') {
                str2 = str2 + "\\r";
            } else if (c == '\t') {
                str2 = str2 + "\\t";
            } else {
                str2 = str2 + c;
            }
        }
        return str2;
    }

    @Override // java.lang.Comparable
    public int compareTo(Object obj) {
        if (obj instanceof NSString) {
            return getContent().compareTo(((NSString) obj).getContent());
        }
        if (obj instanceof String) {
            return getContent().compareTo((String) obj);
        }
        return -1;
    }
}
