package com.inuker.bluetooth.library.channel;

import android.os.Handler;
import android.os.Looper;
import com.inuker.bluetooth.library.utils.BluetoothLog;
import java.util.concurrent.TimeoutException;

/* loaded from: classes2.dex */
public class Timer {
    private static TimerCallback mCallback;
    private static Handler mHandler = new Handler(Looper.getMainLooper());

    public static abstract class TimerCallback implements Runnable {
        private String name;

        public abstract void onTimerCallback() throws TimeoutException;

        public TimerCallback(String str) {
            this.name = str;
        }

        public String getName() {
            return this.name;
        }

        @Override // java.lang.Runnable
        public final void run() {
            BluetoothLog.e(String.format("%s: Timer expired!!!", this.name));
            try {
                onTimerCallback();
            } catch (TimeoutException e) {
                BluetoothLog.e(e);
            }
            TimerCallback unused = Timer.mCallback = null;
        }
    }

    public static synchronized void stop() {
        synchronized (Timer.class) {
            mHandler.removeCallbacksAndMessages(null);
            mCallback = null;
        }
    }

    public static synchronized boolean isRunning() {
        boolean z;
        synchronized (Timer.class) {
            z = mCallback != null;
        }
        return z;
    }

    public static synchronized String getName() {
        String name;
        synchronized (Timer.class) {
            name = isRunning() ? mCallback.getName() : "";
        }
        return name;
    }

    public static synchronized void start(TimerCallback timerCallback, long j) {
        synchronized (Timer.class) {
            mHandler.removeCallbacksAndMessages(null);
            Looper myLooper = Looper.myLooper();
            if (myLooper == null) {
                myLooper = Looper.getMainLooper();
            }
            Handler handler = new Handler(myLooper);
            mHandler = handler;
            handler.postDelayed(timerCallback, j);
            mCallback = timerCallback;
        }
    }
}
