package com.zhuoting.health.login.facebook;

import android.app.Activity;
import android.content.Intent;
import com.facebook.AccessToken;
import com.facebook.CallbackManager;
import com.facebook.FacebookCallback;
import com.facebook.FacebookException;
import com.facebook.GraphRequest;
import com.facebook.GraphResponse;
import com.facebook.gamingservices.cloudgaming.internal.SDKConstants;
import com.facebook.login.LoginManager;
import com.facebook.login.LoginResult;
import com.zhuoting.health.tools.ToastUtil;
import com.zhuoting.healthd.R;
import java.util.Arrays;
import java.util.List;
import org.json.JSONException;
import org.json.JSONObject;

/* loaded from: classes2.dex */
public class FaceBookLogin {
    public static FaceBookLogin faceBookLogin;
    private Activity activity;
    private CallbackManager callbackManager;
    private List<String> permissions;

    private FaceBookLogin(final Activity activity) {
        this.activity = activity;
        if (AccessToken.getCurrentAccessToken() != null) {
            AccessToken currentAccessToken = AccessToken.getCurrentAccessToken();
            activity.sendBroadcast(new Intent("com.login.facebook").putExtra(SDKConstants.PARAM_ACCESS_TOKEN, currentAccessToken.getToken()).putExtra("openID", currentAccessToken.getUserId()));
        } else {
            this.callbackManager = CallbackManager.Factory.create();
            LoginManager.getInstance().registerCallback(this.callbackManager, new FacebookCallback<LoginResult>() { // from class: com.zhuoting.health.login.facebook.FaceBookLogin.1
                @Override // com.facebook.FacebookCallback
                public void onSuccess(LoginResult loginResult) {
                    ToastUtil.getInstance(activity).getToast(activity.getString(R.string.authorization_succeeded));
                    AccessToken accessToken = loginResult.getAccessToken();
                    activity.sendBroadcast(new Intent("com.login.facebook").putExtra(SDKConstants.PARAM_ACCESS_TOKEN, accessToken.getToken()).putExtra("openID", accessToken.getUserId()));
                }

                @Override // com.facebook.FacebookCallback
                public void onCancel() {
                    ToastUtil.getInstance(activity).getToast(activity.getString(R.string.authorization_cancle));
                }

                @Override // com.facebook.FacebookCallback
                public void onError(FacebookException facebookException) {
                    ToastUtil.getInstance(activity).getToast(activity.getString(R.string.authorization_failed));
                }
            });
            this.permissions = Arrays.asList("email", "user_photos", "user_birthday", "public_profile", "user_age_range", "user_gender");
        }
    }

    public static synchronized FaceBookLogin getInstance(Activity activity) {
        FaceBookLogin faceBookLogin2;
        synchronized (FaceBookLogin.class) {
            if (faceBookLogin == null) {
                faceBookLogin = new FaceBookLogin(activity);
            }
            faceBookLogin2 = faceBookLogin;
        }
        return faceBookLogin2;
    }

    public void login() {
        LoginManager.getInstance().logInWithReadPermissions(this.activity, this.permissions);
    }

    public CallbackManager getCallbackManager() {
        return this.callbackManager;
    }

    public void clear() {
        LoginManager.getInstance().logOut();
        this.callbackManager = null;
        faceBookLogin = null;
    }

    private void getUserProfile(AccessToken accessToken) {
        GraphRequest.newMeRequest(accessToken, new GraphRequest.GraphJSONObjectCallback() { // from class: com.zhuoting.health.login.facebook.FaceBookLogin.2
            @Override // com.facebook.GraphRequest.GraphJSONObjectCallback
            public void onCompleted(JSONObject jSONObject, GraphResponse graphResponse) {
                try {
                    jSONObject.getString("last_name");
                    jSONObject.getString("email");
                    jSONObject.getString("id");
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        });
    }
}
