package com.zhuoting.health.tools;

import android.content.Context;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

/* loaded from: classes2.dex */
public class DBHelper extends SQLiteOpenHelper {
    public static final String DATABASE_NAME = "health.db";
    private static final int DATABASE_VERSION = 17;
    private static DBHelper dbHelper;

    public static synchronized SQLiteDatabase getInstance(Context context) {
        SQLiteDatabase writableDatabase;
        synchronized (DBHelper.class) {
            if (dbHelper == null) {
                dbHelper = new DBHelper(context);
            }
            writableDatabase = dbHelper.getWritableDatabase();
        }
        return writableDatabase;
    }

    public DBHelper(Context context) {
        super(context, DATABASE_NAME, (SQLiteDatabase.CursorFactory) null, 17);
    }

    @Override // android.database.sqlite.SQLiteOpenHelper
    public void onCreate(SQLiteDatabase sQLiteDatabase) {
        sQLiteDatabase.execSQL("CREATE TABLE if not exists sport (id integer PRIMARY KEY AUTOINCREMENT NOT NULL,timeFormet varchar(128),begindate integer(128) unique on conflict replace,step integer(128),des integer(128),cakl integer(128),enddate integer(128),isUpload integer(128));");
        sQLiteDatabase.execSQL("CREATE TABLE if not exists sleep (id integer PRIMARY KEY AUTOINCREMENT NOT NULL,beginTime integer(128) unique on conflict replace,endTime integer(128),dsCount integer(128),qsCount integer(128),dsTimes integer(128),qsTimes integer(128),mlist text(512),timeFormet varchar(128),isUpload integer(128));");
        sQLiteDatabase.execSQL("CREATE TABLE if not exists blood (id integer PRIMARY KEY AUTOINCREMENT NOT NULL,rtime integer(128) unique on conflict replace,rtimeFormat varchar(128),SBP integer(128),DBP integer(128),isUpload integer(128), isInflated integer(128));");
        sQLiteDatabase.execSQL("CREATE TABLE if not exists heart (id integer PRIMARY KEY AUTOINCREMENT NOT NULL,rtime integer(128) unique on conflict replace,rtimeFormat varchar(128),heartTimes integer(128),isUpload integer(128));");
        sQLiteDatabase.execSQL("CREATE TABLE if not exists spo2 (id integer PRIMARY KEY AUTOINCREMENT NOT NULL,stime integer(128) unique on conflict replace,stimeFormat varchar(128),spo2 integer(128),breathPer integer(128),cvrr integer(128),hrv integer(128),tempInteger integer(128),tempDouble integer(128), bodyFatInteger integer(128), bodyFatDouble integer(128), bloodSugar integer(128), isUpload integer(128),isBreathPerUpload integer(128),isHrvUpload integer(128),isTempUpload integer(128),isBodyFatUpload integer(128), isBloodSugarUpload integer(128));");
        sQLiteDatabase.execSQL("CREATE TABLE if not exists hrv (id integer PRIMARY KEY AUTOINCREMENT NOT NULL,stimeFormat varchar(128),heart varchar(128),bp varchar(128),hrv varchar(128),maxBP integer(128),minBP integer(128), afflag integer(10), qrstype integer(10),age integer(10),sex integer(10),isUpload integer(128));");
        sQLiteDatabase.execSQL("CREATE TABLE if not exists dial (id integer PRIMARY KEY AUTOINCREMENT NOT NULL,dialId varchar(11),name varchar(128),fileName varchar(128) unique on conflict replace,code varchar(128),width varchar(128),height varchar(128),deviceType varchar(128));");
        upgrade(sQLiteDatabase);
    }

    @Override // android.database.sqlite.SQLiteOpenHelper
    public void onUpgrade(SQLiteDatabase sQLiteDatabase, int i, int i2) {
        if (i < i2) {
            upgrade(sQLiteDatabase);
        }
    }

    private void upgrade(SQLiteDatabase sQLiteDatabase) {
        if (!checkColumnExist(sQLiteDatabase, "sleep", "isUpload")) {
            sQLiteDatabase.execSQL("ALTER TABLE sleep ADD COLUMN isUpload INTEGER DEFAULT 0");
        }
        if (!checkColumnExist(sQLiteDatabase, "sleep", "isApkAmdUpload")) {
            sQLiteDatabase.execSQL("ALTER TABLE sleep ADD COLUMN isApkAmdUpload INTEGER DEFAULT 0");
        }
        if (!checkColumnExist(sQLiteDatabase, "hrv", "afflag")) {
            sQLiteDatabase.execSQL("ALTER TABLE hrv ADD COLUMN afflag INTEGER DEFAULT 0");
            sQLiteDatabase.execSQL("ALTER TABLE hrv ADD COLUMN qrstype INTEGER DEFAULT 0");
        }
        if (!checkColumnExist(sQLiteDatabase, "hrv", "isApkAmdUpload")) {
            sQLiteDatabase.execSQL("ALTER TABLE hrv ADD COLUMN isApkAmdUpload INTEGER DEFAULT 0");
        }
        if (!checkColumnExist(sQLiteDatabase, "spo2", "isBreathPerUpload")) {
            sQLiteDatabase.execSQL("ALTER TABLE spo2 ADD COLUMN isBreathPerUpload INTEGER DEFAULT 0");
            sQLiteDatabase.execSQL("ALTER TABLE spo2 ADD COLUMN isHrvUpload INTEGER DEFAULT 0");
            sQLiteDatabase.execSQL("ALTER TABLE spo2 ADD COLUMN isTempUpload INTEGER DEFAULT 0");
        }
        if (!checkColumnExist(sQLiteDatabase, "spo2", "isBloodSugarUpload")) {
            sQLiteDatabase.execSQL("ALTER TABLE spo2 ADD COLUMN bodyFatInteger INTEGER DEFAULT 0");
            sQLiteDatabase.execSQL("ALTER TABLE spo2 ADD COLUMN bodyFatDouble INTEGER DEFAULT 0");
            sQLiteDatabase.execSQL("ALTER TABLE spo2 ADD COLUMN bloodSugar INTEGER DEFAULT 0");
            sQLiteDatabase.execSQL("ALTER TABLE spo2 ADD COLUMN isBodyFatUpload INTEGER DEFAULT 0");
            sQLiteDatabase.execSQL("ALTER TABLE spo2 ADD COLUMN isBloodSugarUpload INTEGER DEFAULT 0");
        }
        if (!checkColumnExist(sQLiteDatabase, "spo2", "isApkAmdUpload")) {
            sQLiteDatabase.execSQL("ALTER TABLE spo2 ADD COLUMN isApkAmdUpload INTEGER DEFAULT 0");
        }
        if (!checkColumnExist(sQLiteDatabase, "hrv", "sex")) {
            sQLiteDatabase.execSQL("ALTER TABLE hrv ADD COLUMN sex INTEGER DEFAULT 0");
            sQLiteDatabase.execSQL("ALTER TABLE hrv ADD COLUMN age INTEGER DEFAULT 0");
        }
        if (!checkColumnExist(sQLiteDatabase, "blood", "isInflated")) {
            sQLiteDatabase.execSQL("ALTER TABLE blood ADD COLUMN isInflated INTEGER DEFAULT 0");
        }
        if (!checkColumnExist(sQLiteDatabase, "blood", "isApkAmdUpload")) {
            sQLiteDatabase.execSQL("ALTER TABLE blood ADD COLUMN isApkAmdUpload INTEGER DEFAULT 0");
        }
        if (!checkColumnExist(sQLiteDatabase, "heart", "isApkAmdUpload")) {
            sQLiteDatabase.execSQL("ALTER TABLE heart ADD COLUMN isApkAmdUpload INTEGER DEFAULT 0");
        }
        sQLiteDatabase.execSQL("CREATE TABLE if not exists dial (id integer PRIMARY KEY AUTOINCREMENT NOT NULL,dialId varchar(11),name varchar(128),fileName varchar(128) unique on conflict replace,code varchar(128),width varchar(128),height varchar(128),deviceType varchar(128));");
    }

    /* JADX WARN: Code restructure failed: missing block: B:26:0x003f, code lost:
    
        if (r0.isClosed() == false) goto L41;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public boolean checkColumnExist(android.database.sqlite.SQLiteDatabase r5, java.lang.String r6, java.lang.String r7) {
        /*
            r4 = this;
            r0 = 0
            r1 = 0
            java.lang.StringBuilder r2 = new java.lang.StringBuilder     // Catch: java.lang.Throwable -> L33 java.lang.Exception -> L35
            r2.<init>()     // Catch: java.lang.Throwable -> L33 java.lang.Exception -> L35
            java.lang.String r3 = "SELECT * FROM "
            r2.append(r3)     // Catch: java.lang.Throwable -> L33 java.lang.Exception -> L35
            r2.append(r6)     // Catch: java.lang.Throwable -> L33 java.lang.Exception -> L35
            java.lang.String r6 = " LIMIT 0"
            r2.append(r6)     // Catch: java.lang.Throwable -> L33 java.lang.Exception -> L35
            java.lang.String r6 = r2.toString()     // Catch: java.lang.Throwable -> L33 java.lang.Exception -> L35
            android.database.Cursor r0 = r5.rawQuery(r6, r0)     // Catch: java.lang.Throwable -> L33 java.lang.Exception -> L35
            if (r0 == 0) goto L27
            int r5 = r0.getColumnIndex(r7)     // Catch: java.lang.Throwable -> L33 java.lang.Exception -> L35
            r6 = -1
            if (r5 == r6) goto L27
            r5 = 1
            r1 = r5
        L27:
            if (r0 == 0) goto L42
            boolean r5 = r0.isClosed()
            if (r5 != 0) goto L42
        L2f:
            r0.close()
            goto L42
        L33:
            r5 = move-exception
            goto L43
        L35:
            r5 = move-exception
            r5.getStackTrace()     // Catch: java.lang.Throwable -> L33
            if (r0 == 0) goto L42
            boolean r5 = r0.isClosed()
            if (r5 != 0) goto L42
            goto L2f
        L42:
            return r1
        L43:
            if (r0 == 0) goto L4e
            boolean r6 = r0.isClosed()
            if (r6 != 0) goto L4e
            r0.close()
        L4e:
            throw r5
        */
        throw new UnsupportedOperationException("Method not decompiled: com.zhuoting.health.tools.DBHelper.checkColumnExist(android.database.sqlite.SQLiteDatabase, java.lang.String, java.lang.String):boolean");
    }
}
