package com.zhuoting.health.tools;

import android.app.Activity;
import android.content.Context;
import android.net.wifi.WifiInfo;
import android.net.wifi.WifiManager;
import android.os.Build;
import android.provider.Settings;
import android.telephony.TelephonyManager;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;
import com.yanzhenjie.permission.Permission;
import com.zhuoting.healthd.R;
import java.lang.reflect.Method;
import java.net.NetworkInterface;
import java.net.SocketException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Enumeration;
import java.util.Formatter;
import java.util.Random;

/* loaded from: classes2.dex */
public class UUIDUtils {
    public static String generateUUID(Activity activity) {
        Exception e;
        String str;
        if (Build.VERSION.SDK_INT >= 23 && ContextCompat.checkSelfPermission(activity, "android.permission.ACCESS_WIFI_STATE") != 0) {
            if (!ActivityCompat.shouldShowRequestPermissionRationale(activity, "android.permission.ACCESS_WIFI_STATE") && !Tools.readBoolean("ACCESS_WIFI_STATE", activity, false)) {
                activity.requestPermissions(new String[]{"android.permission.ACCESS_WIFI_STATE"}, 1);
                Tools.saveBoolean("ACCESS_WIFI_STATE", true, activity);
                return null;
            }
            Tools.showAlert3(activity, activity.getString(R.string.permission_read_phone_state_access_wifi_state));
            return null;
        }
        try {
            str = getAndroidId(activity) + getDeviceSerial() + getDeviceMac(activity);
            try {
                if (str.trim().equals("")) {
                    str = String.valueOf(System.currentTimeMillis());
                }
                String mD5String = getMD5String(str);
                if (mD5String.length() < 36) {
                    return mD5String + getRandomString(36 - mD5String.length());
                }
                return mD5String.substring(0, 36);
            } catch (Exception e2) {
                e = e2;
                e.printStackTrace();
                return str;
            }
        } catch (Exception e3) {
            e = e3;
            str = "";
        }
    }

    private static String getDeviceId(Context context) {
        String simSerialNumber;
        try {
            if (Build.VERSION.SDK_INT >= 23) {
                if (ContextCompat.checkSelfPermission(context, Permission.READ_PHONE_STATE) != 0) {
                    ((Activity) context).requestPermissions(new String[]{Permission.READ_PHONE_STATE}, 1);
                    return "";
                }
                if (ContextCompat.checkSelfPermission(context, "android.permission.READ_PRIVILEGED_PHONE_STATE") != 0) {
                    ((Activity) context).requestPermissions(new String[]{"android.permission.READ_PRIVILEGED_PHONE_STATE"}, 1);
                    return "";
                }
            }
            TelephonyManager telephonyManager = (TelephonyManager) context.getSystemService("phone");
            if (Build.VERSION.SDK_INT >= 26) {
                simSerialNumber = telephonyManager.getImei();
            } else {
                simSerialNumber = telephonyManager.getSimSerialNumber();
            }
            String str = simSerialNumber;
            System.out.println("chong--------imei==" + str);
            return str;
        } catch (Exception e) {
            System.out.println("chong--------imei==error==");
            e.printStackTrace();
            return "";
        }
    }

    private static String getAndroidId(Context context) {
        try {
            return Settings.Secure.getString(context.getContentResolver(), "android_id");
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    private static String getDeviceSerial() throws Exception {
        try {
            if (Build.VERSION.SDK_INT >= 9) {
                return Build.SERIAL;
            }
            Method declaredMethod = Class.forName("android.os.Build").getDeclaredMethod("getString", Class.forName("java.lang.String"));
            if (!declaredMethod.isAccessible()) {
                declaredMethod.setAccessible(true);
            }
            return (String) declaredMethod.invoke(new Build(), "ro.serialno");
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    private static String getDeviceMac(Context context) {
        try {
            if (Build.VERSION.SDK_INT >= 23 && ContextCompat.checkSelfPermission(context, "android.permission.ACCESS_WIFI_STATE") != 0) {
                ((Activity) context).requestPermissions(new String[]{"android.permission.ACCESS_WIFI_STATE"}, 1);
            }
            if (Build.VERSION.SDK_INT >= 24) {
                return getMachineHardwareAddress();
            }
            WifiInfo connectionInfo = ((WifiManager) context.getSystemService("wifi")).getConnectionInfo();
            return connectionInfo != null ? connectionInfo.getMacAddress() : "";
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    private static String getMachineHardwareAddress() {
        Enumeration<NetworkInterface> enumeration;
        String str = null;
        try {
            enumeration = NetworkInterface.getNetworkInterfaces();
        } catch (SocketException e) {
            e.printStackTrace();
            enumeration = null;
        }
        if (enumeration == null) {
            return null;
        }
        while (enumeration.hasMoreElements()) {
            try {
                str = bytesToString(enumeration.nextElement().getHardwareAddress());
            } catch (SocketException e2) {
                e2.printStackTrace();
            }
            if (str != null) {
                break;
            }
        }
        return str;
    }

    private static String bytesToString(byte[] bArr) {
        if (bArr == null || bArr.length == 0) {
            return null;
        }
        StringBuilder sb = new StringBuilder();
        for (byte b : bArr) {
            sb.append(String.format("%02X:", Byte.valueOf(b)));
        }
        if (sb.length() > 0) {
            sb.deleteCharAt(sb.length() - 1);
        }
        return sb.toString();
    }

    private static String getMD5String(String str) throws NoSuchAlgorithmException {
        byte[] digest = MessageDigest.getInstance("SHA1").digest(str.getBytes());
        Formatter formatter = new Formatter();
        int length = digest.length;
        for (int i = 0; i < length; i++) {
            Object[] objArr = {Byte.valueOf(digest[i])};
            if (i == 4 || i == 7 || i == 10 || i == 13) {
                formatter.format("%s", "-");
            } else {
                formatter.format("%02x", objArr);
            }
        }
        return formatter.toString();
    }

    private static String getRandomString(int i) {
        Random random = new Random();
        StringBuffer stringBuffer = new StringBuffer();
        for (int i2 = 0; i2 < i; i2++) {
            stringBuffer.append("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789".charAt(random.nextInt(62)));
        }
        return stringBuffer.toString();
    }
}
