package com.zhuoting.health.view.chart.renderer;

import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.drawable.Drawable;
import com.zhuoting.health.view.chart.animation.ChartAnimator;
import com.zhuoting.health.view.chart.data.CandleData;
import com.zhuoting.health.view.chart.data.CandleEntry;
import com.zhuoting.health.view.chart.highlight.Highlight;
import com.zhuoting.health.view.chart.interfaces.dataprovider.CandleDataProvider;
import com.zhuoting.health.view.chart.interfaces.datasets.ICandleDataSet;
import com.zhuoting.health.view.chart.interfaces.datasets.ILineScatterCandleRadarDataSet;
import com.zhuoting.health.view.chart.utils.MPPointD;
import com.zhuoting.health.view.chart.utils.MPPointF;
import com.zhuoting.health.view.chart.utils.Transformer;
import com.zhuoting.health.view.chart.utils.Utils;
import com.zhuoting.health.view.chart.utils.ViewPortHandler;
import java.util.List;

/* loaded from: classes2.dex */
public class CandleStickChartRenderer extends LineScatterCandleRadarRenderer {
    private float[] mBodyBuffers;
    protected CandleDataProvider mChart;
    private float[] mCloseBuffers;
    private float[] mOpenBuffers;
    private float[] mRangeBuffers;
    private float[] mShadowBuffers;

    @Override // com.zhuoting.health.view.chart.renderer.DataRenderer
    public void drawExtras(Canvas canvas) {
    }

    @Override // com.zhuoting.health.view.chart.renderer.DataRenderer
    public void initBuffers() {
    }

    public CandleStickChartRenderer(CandleDataProvider candleDataProvider, ChartAnimator chartAnimator, ViewPortHandler viewPortHandler) {
        super(chartAnimator, viewPortHandler);
        this.mShadowBuffers = new float[8];
        this.mBodyBuffers = new float[4];
        this.mRangeBuffers = new float[4];
        this.mOpenBuffers = new float[4];
        this.mCloseBuffers = new float[4];
        this.mChart = candleDataProvider;
    }

    @Override // com.zhuoting.health.view.chart.renderer.DataRenderer
    public void drawData(Canvas canvas) {
        for (T t : this.mChart.getCandleData().getDataSets()) {
            if (t.isVisible()) {
                drawDataSet(canvas, t);
            }
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    protected void drawDataSet(Canvas canvas, ICandleDataSet iCandleDataSet) {
        int neutralColor;
        int shadowColor;
        int neutralColor2;
        int increasingColor;
        int decreasingColor;
        Transformer transformer = this.mChart.getTransformer(iCandleDataSet.getAxisDependency());
        float phaseY = this.mAnimator.getPhaseY();
        float barSpace = iCandleDataSet.getBarSpace();
        boolean showCandleBar = iCandleDataSet.getShowCandleBar();
        this.mXBounds.set(this.mChart, iCandleDataSet);
        this.mRenderPaint.setStrokeWidth(iCandleDataSet.getShadowWidth());
        for (int i = this.mXBounds.min; i <= this.mXBounds.range + this.mXBounds.min; i++) {
            CandleEntry candleEntry = (CandleEntry) iCandleDataSet.getEntryForIndex(i);
            if (candleEntry != null) {
                float x = candleEntry.getX();
                float open = candleEntry.getOpen();
                float close = candleEntry.getClose();
                float high = candleEntry.getHigh();
                float low = candleEntry.getLow();
                if (showCandleBar) {
                    float[] fArr = this.mShadowBuffers;
                    fArr[0] = x;
                    fArr[2] = x;
                    fArr[4] = x;
                    fArr[6] = x;
                    if (open > close) {
                        fArr[1] = high * phaseY;
                        fArr[3] = open * phaseY;
                        fArr[5] = low * phaseY;
                        fArr[7] = close * phaseY;
                    } else if (open < close) {
                        fArr[1] = high * phaseY;
                        fArr[3] = close * phaseY;
                        fArr[5] = low * phaseY;
                        fArr[7] = open * phaseY;
                    } else {
                        fArr[1] = high * phaseY;
                        fArr[3] = open * phaseY;
                        fArr[5] = low * phaseY;
                        fArr[7] = fArr[3];
                    }
                    transformer.pointValuesToPixel(fArr);
                    if (!iCandleDataSet.getShadowColorSameAsCandle()) {
                        Paint paint = this.mRenderPaint;
                        if (iCandleDataSet.getShadowColor() == 1122867) {
                            shadowColor = iCandleDataSet.getColor(i);
                        } else {
                            shadowColor = iCandleDataSet.getShadowColor();
                        }
                        paint.setColor(shadowColor);
                    } else if (open > close) {
                        Paint paint2 = this.mRenderPaint;
                        if (iCandleDataSet.getDecreasingColor() == 1122867) {
                            decreasingColor = iCandleDataSet.getColor(i);
                        } else {
                            decreasingColor = iCandleDataSet.getDecreasingColor();
                        }
                        paint2.setColor(decreasingColor);
                    } else if (open < close) {
                        Paint paint3 = this.mRenderPaint;
                        if (iCandleDataSet.getIncreasingColor() == 1122867) {
                            increasingColor = iCandleDataSet.getColor(i);
                        } else {
                            increasingColor = iCandleDataSet.getIncreasingColor();
                        }
                        paint3.setColor(increasingColor);
                    } else {
                        Paint paint4 = this.mRenderPaint;
                        if (iCandleDataSet.getNeutralColor() == 1122867) {
                            neutralColor2 = iCandleDataSet.getColor(i);
                        } else {
                            neutralColor2 = iCandleDataSet.getNeutralColor();
                        }
                        paint4.setColor(neutralColor2);
                    }
                    this.mRenderPaint.setStyle(Paint.Style.STROKE);
                    canvas.drawLines(this.mShadowBuffers, this.mRenderPaint);
                    float[] fArr2 = this.mBodyBuffers;
                    fArr2[0] = (x - 0.5f) + barSpace;
                    fArr2[1] = close * phaseY;
                    fArr2[2] = (x + 0.5f) - barSpace;
                    fArr2[3] = open * phaseY;
                    transformer.pointValuesToPixel(fArr2);
                    if (open > close) {
                        this.mRenderPaint.setStyle(iCandleDataSet.getDecreasingPaintStyle());
                        this.mRenderPaint.setColor(iCandleDataSet.getIncreasingColor());
                        float[] fArr3 = this.mBodyBuffers;
                        canvas.drawRoundRect(fArr3[0], fArr3[3], fArr3[2], fArr3[1], 0.0f, 0.0f, this.mRenderPaint);
                        this.mRenderPaint.setColor(iCandleDataSet.getDecreasingColor());
                        float[] fArr4 = this.mBodyBuffers;
                        canvas.drawRoundRect(fArr4[0], fArr4[1], fArr4[2], this.mChart.getHeight(), 0.0f, 0.0f, this.mRenderPaint);
                    } else if (open < close) {
                        if (iCandleDataSet.getIncreasingColor() == 1122867) {
                            this.mRenderPaint.setColor(iCandleDataSet.getColor(i));
                        } else {
                            this.mRenderPaint.setColor(iCandleDataSet.getIncreasingColor());
                        }
                        this.mRenderPaint.setStyle(iCandleDataSet.getIncreasingPaintStyle());
                        this.mRenderPaint.setColor(iCandleDataSet.getDecreasingColor());
                        float[] fArr5 = this.mBodyBuffers;
                        canvas.drawRoundRect(fArr5[0], fArr5[1], fArr5[2], fArr5[3], 0.0f, 0.0f, this.mRenderPaint);
                        this.mRenderPaint.setColor(iCandleDataSet.getIncreasingColor());
                        float[] fArr6 = this.mBodyBuffers;
                        canvas.drawRoundRect(fArr6[0], fArr6[3], fArr6[2], this.mChart.getHeight(), 0.0f, 0.0f, this.mRenderPaint);
                    } else {
                        if (iCandleDataSet.getNeutralColor() == 1122867) {
                            this.mRenderPaint.setColor(iCandleDataSet.getColor(i));
                        } else {
                            this.mRenderPaint.setColor(iCandleDataSet.getNeutralColor());
                        }
                        float[] fArr7 = this.mBodyBuffers;
                        canvas.drawLine(fArr7[0], fArr7[1], fArr7[2], fArr7[3], this.mRenderPaint);
                    }
                } else {
                    float[] fArr8 = this.mRangeBuffers;
                    fArr8[0] = x;
                    fArr8[1] = high * phaseY;
                    fArr8[2] = x;
                    fArr8[3] = low * phaseY;
                    float[] fArr9 = this.mOpenBuffers;
                    fArr9[0] = (x - 0.5f) + barSpace;
                    float f = open * phaseY;
                    fArr9[1] = f;
                    fArr9[2] = x;
                    fArr9[3] = f;
                    float[] fArr10 = this.mCloseBuffers;
                    fArr10[0] = (0.5f + x) - barSpace;
                    float f2 = close * phaseY;
                    fArr10[1] = f2;
                    fArr10[2] = x;
                    fArr10[3] = f2;
                    transformer.pointValuesToPixel(fArr8);
                    transformer.pointValuesToPixel(this.mOpenBuffers);
                    transformer.pointValuesToPixel(this.mCloseBuffers);
                    if (open > close) {
                        if (iCandleDataSet.getDecreasingColor() == 1122867) {
                            neutralColor = iCandleDataSet.getColor(i);
                        } else {
                            neutralColor = iCandleDataSet.getDecreasingColor();
                        }
                    } else if (open < close) {
                        if (iCandleDataSet.getIncreasingColor() == 1122867) {
                            neutralColor = iCandleDataSet.getColor(i);
                        } else {
                            neutralColor = iCandleDataSet.getIncreasingColor();
                        }
                    } else if (iCandleDataSet.getNeutralColor() == 1122867) {
                        neutralColor = iCandleDataSet.getColor(i);
                    } else {
                        neutralColor = iCandleDataSet.getNeutralColor();
                    }
                    this.mRenderPaint.setColor(neutralColor);
                    float[] fArr11 = this.mRangeBuffers;
                    canvas.drawLine(fArr11[0], fArr11[1], fArr11[2], fArr11[3], this.mRenderPaint);
                    float[] fArr12 = this.mOpenBuffers;
                    canvas.drawLine(fArr12[0], fArr12[1], fArr12[2], fArr12[3], this.mRenderPaint);
                    float[] fArr13 = this.mCloseBuffers;
                    canvas.drawLine(fArr13[0], fArr13[1], fArr13[2], fArr13[3], this.mRenderPaint);
                }
            }
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    @Override // com.zhuoting.health.view.chart.renderer.DataRenderer
    public void drawValues(Canvas canvas) {
        int i;
        MPPointF mPPointF;
        float f;
        float f2;
        if (isDrawingValuesAllowed(this.mChart)) {
            List<T> dataSets = this.mChart.getCandleData().getDataSets();
            for (int i2 = 0; i2 < dataSets.size(); i2++) {
                ICandleDataSet iCandleDataSet = (ICandleDataSet) dataSets.get(i2);
                if (shouldDrawValues(iCandleDataSet) && iCandleDataSet.getEntryCount() >= 1) {
                    applyValueTextStyle(iCandleDataSet);
                    Transformer transformer = this.mChart.getTransformer(iCandleDataSet.getAxisDependency());
                    this.mXBounds.set(this.mChart, iCandleDataSet);
                    float[] generateTransformedValuesCandle = transformer.generateTransformedValuesCandle(iCandleDataSet, this.mAnimator.getPhaseX(), this.mAnimator.getPhaseY(), this.mXBounds.min, this.mXBounds.max);
                    float convertDpToPixel = Utils.convertDpToPixel(5.0f);
                    MPPointF mPPointF2 = MPPointF.getInstance(iCandleDataSet.getIconsOffset());
                    mPPointF2.x = Utils.convertDpToPixel(mPPointF2.x);
                    mPPointF2.y = Utils.convertDpToPixel(mPPointF2.y);
                    int i3 = 0;
                    while (i3 < generateTransformedValuesCandle.length) {
                        float f3 = generateTransformedValuesCandle[i3];
                        float f4 = generateTransformedValuesCandle[i3 + 1];
                        if (!this.mViewPortHandler.isInBoundsRight(f3)) {
                            break;
                        }
                        if (this.mViewPortHandler.isInBoundsLeft(f3) && this.mViewPortHandler.isInBoundsY(f4)) {
                            int i4 = i3 / 2;
                            CandleEntry candleEntry = (CandleEntry) iCandleDataSet.getEntryForIndex(this.mXBounds.min + i4);
                            if (iCandleDataSet.isDrawValuesEnabled()) {
                                f = f4;
                                f2 = f3;
                                i = i3;
                                mPPointF = mPPointF2;
                                drawValue(canvas, iCandleDataSet.getValueFormatter(), candleEntry.getHigh(), candleEntry, i2, f3, f4 - convertDpToPixel, iCandleDataSet.getValueTextColor(i4));
                            } else {
                                f = f4;
                                f2 = f3;
                                i = i3;
                                mPPointF = mPPointF2;
                            }
                            if (candleEntry.getIcon() != null && iCandleDataSet.isDrawIconsEnabled()) {
                                Drawable icon = candleEntry.getIcon();
                                Utils.drawImage(canvas, icon, (int) (f2 + mPPointF.x), (int) (f + mPPointF.y), icon.getIntrinsicWidth(), icon.getIntrinsicHeight());
                            }
                        } else {
                            i = i3;
                            mPPointF = mPPointF2;
                        }
                        i3 = i + 2;
                        mPPointF2 = mPPointF;
                    }
                    MPPointF.recycleInstance(mPPointF2);
                }
            }
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    @Override // com.zhuoting.health.view.chart.renderer.DataRenderer
    public void drawHighlighted(Canvas canvas, Highlight[] highlightArr) {
        CandleData candleData = this.mChart.getCandleData();
        for (Highlight highlight : highlightArr) {
            ILineScatterCandleRadarDataSet iLineScatterCandleRadarDataSet = (ICandleDataSet) candleData.getDataSetByIndex(highlight.getDataSetIndex());
            if (iLineScatterCandleRadarDataSet != null && iLineScatterCandleRadarDataSet.isHighlightEnabled()) {
                CandleEntry candleEntry = (CandleEntry) iLineScatterCandleRadarDataSet.getEntryForXValue(highlight.getX(), highlight.getY());
                if (isInBoundsX(candleEntry, iLineScatterCandleRadarDataSet)) {
                    MPPointD pixelForValues = this.mChart.getTransformer(iLineScatterCandleRadarDataSet.getAxisDependency()).getPixelForValues(candleEntry.getX(), ((candleEntry.getLow() * this.mAnimator.getPhaseY()) + (candleEntry.getHigh() * this.mAnimator.getPhaseY())) / 2.0f);
                    highlight.setDraw((float) pixelForValues.x, (float) pixelForValues.y);
                    drawHighlightLines(canvas, (float) pixelForValues.x, (float) pixelForValues.y, iLineScatterCandleRadarDataSet);
                }
            }
        }
    }
}
