package com.zhuoting.health.zxing.decoding;

import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.util.Log;
import com.google.zxing.BinaryBitmap;
import com.google.zxing.DecodeHintType;
import com.google.zxing.MultiFormatReader;
import com.google.zxing.Result;
import com.google.zxing.common.HybridBinarizer;
import com.google.zxing.qrcode.QRCodeReader;
import com.zhuoting.health.zxing.activity.CaptureActivity;
import com.zhuoting.health.zxing.camera.CameraManager;
import com.zhuoting.health.zxing.camera.PlanarYUVLuminanceSource;
import com.zhuoting.healthd.R;
import java.util.Map;

/* loaded from: classes2.dex */
final class DecodeHandler extends Handler {
    private static final String TAG = "DecodeHandler";
    private final CaptureActivity activity;
    private QRCodeReader mQRCodeReader;
    private MultiFormatReader multiFormatReader;

    DecodeHandler(CaptureActivity captureActivity, Map<DecodeHintType, Object> map) {
        this.multiFormatReader = null;
        this.activity = captureActivity;
        if (map != null) {
            MultiFormatReader multiFormatReader = new MultiFormatReader();
            this.multiFormatReader = multiFormatReader;
            multiFormatReader.setHints(map);
            return;
        }
        this.mQRCodeReader = new QRCodeReader();
    }

    @Override // android.os.Handler
    public void handleMessage(Message message) {
        int i = message.what;
        if (i == R.id.decode) {
            decode((byte[]) message.obj, message.arg1, message.arg2);
        } else if (i == R.id.quit) {
            Looper.myLooper().quit();
        }
    }

    private void decode(byte[] bArr, int i, int i2) {
        Result decodeWithState;
        long currentTimeMillis = System.currentTimeMillis();
        byte[] bArr2 = new byte[bArr.length];
        for (int i3 = 0; i3 < i2; i3++) {
            for (int i4 = 0; i4 < i; i4++) {
                bArr2[(((i4 * i2) + i2) - i3) - 1] = bArr[(i3 * i) + i4];
            }
        }
        PlanarYUVLuminanceSource buildLuminanceSource = CameraManager.get().buildLuminanceSource(bArr2, i2, i);
        Result result = null;
        if (buildLuminanceSource != null) {
            BinaryBitmap binaryBitmap = new BinaryBitmap(new HybridBinarizer(buildLuminanceSource));
            try {
                QRCodeReader qRCodeReader = this.mQRCodeReader;
                if (qRCodeReader != null) {
                    decodeWithState = qRCodeReader.decode(binaryBitmap);
                } else {
                    MultiFormatReader multiFormatReader = this.multiFormatReader;
                    if (multiFormatReader != null) {
                        decodeWithState = multiFormatReader.decodeWithState(binaryBitmap);
                    } else {
                        System.out.println("chong------没有解析工具");
                    }
                }
                result = decodeWithState;
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        if (result != null) {
            long currentTimeMillis2 = System.currentTimeMillis();
            Log.d(TAG, "Found barcode (" + (currentTimeMillis2 - currentTimeMillis) + " ms):\n" + result.toString());
            Message.obtain(this.activity.getHandler(), R.id.decode_succeeded, result).sendToTarget();
            return;
        }
        Message.obtain(this.activity.getHandler(), R.id.decode_failed).sendToTarget();
    }
}
