package no.nordicsemi.android.support.v18.scanner;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.os.Handler;
import android.os.SystemClock;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import kotlin.jvm.internal.LongCompanionObject;
import no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat;

/* loaded from: classes2.dex */
class BluetoothLeScannerImplJB extends BluetoothLeScannerCompat implements BluetoothAdapter.LeScanCallback {
    private Handler mPowerSaveHandler;
    private long mPowerSaveRestInterval;
    private long mPowerSaveScanInterval;
    private Runnable mPowerSaveSleepRunnable = new Runnable() { // from class: no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerImplJB.1
        @Override // java.lang.Runnable
        public void run() {
            if (BluetoothLeScannerImplJB.this.mBluetoothAdapter == null || BluetoothLeScannerImplJB.this.mPowerSaveRestInterval <= 0 || BluetoothLeScannerImplJB.this.mPowerSaveScanInterval <= 0) {
                return;
            }
            BluetoothLeScannerImplJB.this.mBluetoothAdapter.stopLeScan(BluetoothLeScannerImplJB.this);
            if (BluetoothLeScannerImplJB.this.mPowerSaveHandler != null) {
                BluetoothLeScannerImplJB.this.mPowerSaveHandler.postDelayed(BluetoothLeScannerImplJB.this.mPowerSaveScanRunnable, BluetoothLeScannerImplJB.this.mPowerSaveRestInterval);
            }
        }
    };
    private Runnable mPowerSaveScanRunnable = new Runnable() { // from class: no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerImplJB.2
        @Override // java.lang.Runnable
        public void run() {
            if (BluetoothLeScannerImplJB.this.mBluetoothAdapter == null || BluetoothLeScannerImplJB.this.mPowerSaveRestInterval <= 0 || BluetoothLeScannerImplJB.this.mPowerSaveScanInterval <= 0) {
                return;
            }
            BluetoothLeScannerImplJB.this.mBluetoothAdapter.startLeScan(BluetoothLeScannerImplJB.this);
            if (BluetoothLeScannerImplJB.this.mPowerSaveHandler != null) {
                BluetoothLeScannerImplJB.this.mPowerSaveHandler.postDelayed(BluetoothLeScannerImplJB.this.mPowerSaveSleepRunnable, BluetoothLeScannerImplJB.this.mPowerSaveScanInterval);
            }
        }
    };
    private final BluetoothAdapter mBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
    private final Map<ScanCallback, BluetoothLeScannerCompat.ScanCallbackWrapper> mWrappers = new HashMap();

    @Override // no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat
    void startScanInternal(List<ScanFilter> list, ScanSettings scanSettings, ScanCallback scanCallback) {
        boolean isEmpty;
        BluetoothLeUtils.checkAdapterStateOn(this.mBluetoothAdapter);
        if (this.mWrappers.containsKey(scanCallback)) {
            throw new IllegalArgumentException("scanner already started with given callback");
        }
        synchronized (this.mWrappers) {
            isEmpty = this.mWrappers.isEmpty();
            this.mWrappers.put(scanCallback, new BluetoothLeScannerCompat.ScanCallbackWrapper(list, scanSettings, scanCallback));
        }
        setPowerSaveSettings();
        if (isEmpty) {
            this.mBluetoothAdapter.startLeScan(this);
        }
    }

    private void setPowerSaveSettings() {
        long j;
        long j2;
        synchronized (this.mWrappers) {
            Iterator<BluetoothLeScannerCompat.ScanCallbackWrapper> it2 = this.mWrappers.values().iterator();
            j = Long.MAX_VALUE;
            j2 = Long.MAX_VALUE;
            while (it2.hasNext()) {
                ScanSettings scanSettings = it2.next().getScanSettings();
                if (scanSettings.hasPowerSaveMode()) {
                    if (j > scanSettings.getPowerSaveRest()) {
                        j = scanSettings.getPowerSaveRest();
                    }
                    if (j2 > scanSettings.getPowerSaveScan()) {
                        j2 = scanSettings.getPowerSaveScan();
                    }
                }
            }
        }
        if (j < LongCompanionObject.MAX_VALUE && j2 < LongCompanionObject.MAX_VALUE) {
            this.mPowerSaveRestInterval = j;
            this.mPowerSaveScanInterval = j2;
            Handler handler = this.mPowerSaveHandler;
            if (handler == null) {
                this.mPowerSaveHandler = new Handler();
            } else {
                handler.removeCallbacks(this.mPowerSaveScanRunnable);
                this.mPowerSaveHandler.removeCallbacks(this.mPowerSaveSleepRunnable);
            }
            this.mPowerSaveHandler.postDelayed(this.mPowerSaveSleepRunnable, this.mPowerSaveScanInterval);
            return;
        }
        this.mPowerSaveScanInterval = 0L;
        this.mPowerSaveRestInterval = 0L;
        Handler handler2 = this.mPowerSaveHandler;
        if (handler2 != null) {
            handler2.removeCallbacks(this.mPowerSaveScanRunnable);
            this.mPowerSaveHandler.removeCallbacks(this.mPowerSaveSleepRunnable);
        }
    }

    @Override // no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat
    public void stopScan(ScanCallback scanCallback) {
        synchronized (this.mWrappers) {
            BluetoothLeScannerCompat.ScanCallbackWrapper scanCallbackWrapper = this.mWrappers.get(scanCallback);
            if (scanCallbackWrapper == null) {
                return;
            }
            this.mWrappers.remove(scanCallback);
            scanCallbackWrapper.close();
            setPowerSaveSettings();
            if (this.mWrappers.isEmpty()) {
                this.mBluetoothAdapter.stopLeScan(this);
            }
        }
    }

    @Override // no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat
    public void flushPendingScanResults(ScanCallback scanCallback) {
        BluetoothLeUtils.checkAdapterStateOn(this.mBluetoothAdapter);
        if (scanCallback == null) {
            throw new IllegalArgumentException("callback cannot be null!");
        }
        this.mWrappers.get(scanCallback).flushPendingScanResults();
    }

    @Override // android.bluetooth.BluetoothAdapter.LeScanCallback
    public void onLeScan(BluetoothDevice bluetoothDevice, int i, byte[] bArr) {
        ScanResult scanResult = new ScanResult(bluetoothDevice, ScanRecord.parseFromBytes(bArr), i, SystemClock.elapsedRealtimeNanos());
        synchronized (this.mWrappers) {
            Iterator<BluetoothLeScannerCompat.ScanCallbackWrapper> it2 = this.mWrappers.values().iterator();
            while (it2.hasNext()) {
                it2.next().handleScanResult(scanResult);
            }
        }
    }
}
