package org.achartengine.chart;

import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.RectF;
import android.graphics.drawable.GradientDrawable;
import com.zhuoting.health.view.chart.utils.Utils;
import java.util.List;
import org.achartengine.model.XYMultipleSeriesDataset;
import org.achartengine.model.XYSeries;
import org.achartengine.renderer.SimpleSeriesRenderer;
import org.achartengine.renderer.XYMultipleSeriesRenderer;

/* loaded from: classes2.dex */
public class BarChart extends XYChart {
    private static final int SHAPE_WIDTH = 12;
    public static final String TYPE = "Bar";
    protected Type mType;

    public enum Type {
        DEFAULT,
        STACKED
    }

    @Override // org.achartengine.chart.XYChart
    public String getChartType() {
        return TYPE;
    }

    protected float getCoeficient() {
        return 1.0f;
    }

    @Override // org.achartengine.chart.XYChart
    public double getDefaultMinimum() {
        return Utils.DOUBLE_EPSILON;
    }

    @Override // org.achartengine.chart.AbstractChart
    public int getLegendShapeWidth(int i) {
        return 12;
    }

    @Override // org.achartengine.chart.XYChart
    protected boolean isRenderNullValues() {
        return true;
    }

    BarChart() {
        this.mType = Type.DEFAULT;
    }

    BarChart(Type type) {
        this.mType = Type.DEFAULT;
        this.mType = type;
    }

    public BarChart(XYMultipleSeriesDataset xYMultipleSeriesDataset, XYMultipleSeriesRenderer xYMultipleSeriesRenderer, Type type) {
        super(xYMultipleSeriesDataset, xYMultipleSeriesRenderer);
        this.mType = Type.DEFAULT;
        this.mType = type;
    }

    @Override // org.achartengine.chart.XYChart
    protected ClickableArea[] clickableAreasForPoints(List<Float> list, List<Double> list2, float f, int i, int i2) {
        int seriesCount = this.mDataset.getSeriesCount();
        int size = list.size();
        ClickableArea[] clickableAreaArr = new ClickableArea[size / 2];
        float halfDiffX = getHalfDiffX(list, size, seriesCount);
        for (int i3 = 0; i3 < size; i3 += 2) {
            float floatValue = list.get(i3).floatValue();
            int i4 = i3 + 1;
            float floatValue2 = list.get(i4).floatValue();
            if (this.mType == Type.STACKED) {
                clickableAreaArr[i3 / 2] = new ClickableArea(new RectF(floatValue - halfDiffX, Math.min(floatValue2, f), floatValue + halfDiffX, Math.max(floatValue2, f)), list2.get(i3).doubleValue(), list2.get(i4).doubleValue());
            } else {
                float f2 = (floatValue - (seriesCount * halfDiffX)) + (i * 2 * halfDiffX);
                clickableAreaArr[i3 / 2] = new ClickableArea(new RectF(f2, Math.min(floatValue2, f), (2.0f * halfDiffX) + f2, Math.max(floatValue2, f)), list2.get(i3).doubleValue(), list2.get(i4).doubleValue());
            }
        }
        return clickableAreaArr;
    }

    @Override // org.achartengine.chart.XYChart
    public void drawSeries(Canvas canvas, Paint paint, List<Float> list, SimpleSeriesRenderer simpleSeriesRenderer, float f, int i, int i2) {
        int seriesCount = this.mDataset.getSeriesCount();
        int size = list.size();
        paint.setColor(simpleSeriesRenderer.getColor());
        paint.setStyle(Paint.Style.FILL);
        float halfDiffX = getHalfDiffX(list, size, seriesCount);
        for (int i3 = 0; i3 < size; i3 += 2) {
            float floatValue = list.get(i3).floatValue();
            drawBar(canvas, floatValue, f, floatValue, list.get(i3 + 1).floatValue(), halfDiffX, seriesCount, i, paint);
        }
        paint.setColor(simpleSeriesRenderer.getColor());
    }

    protected void drawBar(Canvas canvas, float f, float f2, float f3, float f4, float f5, int i, int i2, Paint paint) {
        int scaleNumber = this.mDataset.getSeriesAt(i2).getScaleNumber();
        if (this.mType == Type.STACKED) {
            drawBar(canvas, f - f5, f4, f3 + f5, f2, scaleNumber, i2, paint);
        } else {
            float f6 = (f - (i * f5)) + (i2 * 2 * f5);
            drawBar(canvas, f6, f4, f6 + (2.0f * f5), f2, scaleNumber, i2, paint);
        }
    }

    private void drawBar(Canvas canvas, float f, float f2, float f3, float f4, int i, int i2, Paint paint) {
        int i3;
        int i4;
        int gradientPartialColor;
        int gradientPartialColor2;
        float f5 = f4;
        SimpleSeriesRenderer seriesRendererAt = this.mRenderer.getSeriesRendererAt(i2);
        if (seriesRendererAt.isGradientEnabled()) {
            float f6 = (float) toScreenPoint(new double[]{Utils.DOUBLE_EPSILON, seriesRendererAt.getGradientStopValue()}, i)[1];
            float f7 = (float) toScreenPoint(new double[]{Utils.DOUBLE_EPSILON, seriesRendererAt.getGradientStartValue()}, i)[1];
            float max = Math.max(f6, Math.min(f2, f5));
            float min = Math.min(f7, Math.max(f2, f5));
            int gradientStopColor = seriesRendererAt.getGradientStopColor();
            int gradientStartColor = seriesRendererAt.getGradientStartColor();
            if (f2 < f6) {
                paint.setColor(gradientStopColor);
                i3 = gradientStartColor;
                i4 = gradientStopColor;
                canvas.drawRect(Math.round(f), Math.round(f2), Math.round(f3), Math.round(max), paint);
                gradientPartialColor = i4;
            } else {
                i3 = gradientStartColor;
                i4 = gradientStopColor;
                gradientPartialColor = getGradientPartialColor(i4, i3, (f7 - max) / (f7 - f6));
            }
            if (f5 > f7) {
                paint.setColor(i3);
                canvas.drawRect(Math.round(f), Math.round(min), Math.round(f3), Math.round(f4), paint);
                gradientPartialColor2 = i3;
            } else {
                gradientPartialColor2 = getGradientPartialColor(i3, i4, (min - f6) / (f7 - f6));
            }
            GradientDrawable gradientDrawable = new GradientDrawable(GradientDrawable.Orientation.BOTTOM_TOP, new int[]{gradientPartialColor2, gradientPartialColor});
            gradientDrawable.setBounds(Math.round(f), Math.round(max), Math.round(f3), Math.round(min));
            gradientDrawable.draw(canvas);
            return;
        }
        if (Math.abs(f2 - f5) < 1.0f) {
            f5 = f2 < f5 ? f2 + 1.0f : f2 - 1.0f;
        }
        canvas.drawRect(Math.round(f), Math.round(f2), Math.round(f3), Math.round(f5), paint);
    }

    private int getGradientPartialColor(int i, int i2, float f) {
        float f2 = 1.0f - f;
        return Color.argb(Math.round((Color.alpha(i) * f) + (Color.alpha(i2) * f2)), Math.round((Color.red(i) * f) + (Color.red(i2) * f2)), Math.round((Color.green(i) * f) + (Color.green(i2) * f2)), Math.round((f * Color.blue(i)) + (f2 * Color.blue(i2))));
    }

    @Override // org.achartengine.chart.XYChart
    protected void drawChartValuesText(Canvas canvas, XYSeries xYSeries, SimpleSeriesRenderer simpleSeriesRenderer, Paint paint, List<Float> list, int i, int i2) {
        int seriesCount = this.mDataset.getSeriesCount();
        int size = list.size();
        float halfDiffX = getHalfDiffX(list, size, seriesCount);
        for (int i3 = 0; i3 < size; i3 += 2) {
            double y = xYSeries.getY(i2 + (i3 / 2));
            if (!isNullValue(y)) {
                float floatValue = list.get(i3).floatValue();
                if (this.mType == Type.DEFAULT) {
                    floatValue += ((i * 2) * halfDiffX) - ((seriesCount - 1.5f) * halfDiffX);
                }
                float f = floatValue;
                if (y >= Utils.DOUBLE_EPSILON) {
                    drawText(canvas, getLabel(simpleSeriesRenderer.getChartValuesFormat(), y), f, list.get(i3 + 1).floatValue() - simpleSeriesRenderer.getChartValuesSpacing(), paint, 0.0f);
                } else {
                    drawText(canvas, getLabel(simpleSeriesRenderer.getChartValuesFormat(), y), f, ((list.get(i3 + 1).floatValue() + simpleSeriesRenderer.getChartValuesTextSize()) + simpleSeriesRenderer.getChartValuesSpacing()) - 3.0f, paint, 0.0f);
                }
            }
        }
    }

    @Override // org.achartengine.chart.AbstractChart
    public void drawLegendShape(Canvas canvas, SimpleSeriesRenderer simpleSeriesRenderer, float f, float f2, int i, Paint paint) {
        canvas.drawRect(f, f2 - 6.0f, f + 12.0f, f2 + 6.0f, paint);
    }

    protected float getHalfDiffX(List<Float> list, int i, int i2) {
        float barWidth = this.mRenderer.getBarWidth();
        if (barWidth > 0.0f) {
            return barWidth / 2.0f;
        }
        float floatValue = (list.get(i - 2).floatValue() - list.get(0).floatValue()) / (i > 2 ? i - 2 : i);
        if (floatValue == 0.0f) {
            floatValue = 10.0f;
        }
        if (this.mType != Type.STACKED) {
            floatValue /= i2;
        }
        return (float) (floatValue / (getCoeficient() * (this.mRenderer.getBarSpacing() + 1.0d)));
    }
}
