package org.achartengine.tools;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.achartengine.chart.AbstractChart;
import org.achartengine.chart.RoundChart;
import org.achartengine.chart.XYChart;
import org.achartengine.renderer.DefaultRenderer;

/* loaded from: classes2.dex */
public class Zoom extends AbstractTool {
    public static final int ZOOM_AXIS_X = 1;
    public static final int ZOOM_AXIS_XY = 0;
    public static final int ZOOM_AXIS_Y = 2;
    private boolean limitsReachedX;
    private boolean limitsReachedY;
    private boolean mZoomIn;
    private List<ZoomListener> mZoomListeners;
    private float mZoomRate;

    public Zoom(AbstractChart abstractChart, boolean z, float f) {
        super(abstractChart);
        this.mZoomListeners = new ArrayList();
        this.limitsReachedX = false;
        this.limitsReachedY = false;
        this.mZoomIn = z;
        setZoomRate(f);
    }

    public void setZoomRate(float f) {
        this.mZoomRate = f;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r9v0 */
    /* JADX WARN: Type inference failed for: r9v1 */
    /* JADX WARN: Type inference failed for: r9v5 */
    public void apply(int i) {
        int i2;
        double d;
        double zoomInLimitX;
        double zoomInLimitY;
        if (this.mChart instanceof XYChart) {
            int scalesCount = this.mRenderer.getScalesCount();
            ?? r9 = 0;
            int i3 = 0;
            while (i3 < scalesCount) {
                double[] range = getRange(i3);
                checkRange(range, i3);
                double[] zoomLimits = this.mRenderer.getZoomLimits();
                double d2 = (range[r9] + range[1]) / 2.0d;
                double d3 = (range[2] + range[3]) / 2.0d;
                double d4 = range[1] - range[r9];
                double d5 = range[3] - range[2];
                double d6 = d4 / 2.0d;
                double d7 = d2 - d6;
                double d8 = d2 + d6;
                double d9 = d5 / 2.0d;
                double d10 = d3 - d9;
                double d11 = d3 + d9;
                if (i3 == 0) {
                    this.limitsReachedX = (zoomLimits == null || (d7 > zoomLimits[r9] && d8 < zoomLimits[1])) ? r9 : true;
                    this.limitsReachedY = (zoomLimits == null || (d10 > zoomLimits[2] && d11 < zoomLimits[3])) ? r9 : true;
                }
                if (this.mZoomIn) {
                    if (this.mRenderer.isZoomXEnabled() && ((i == 1 || i == 0) && (!this.limitsReachedX || this.mZoomRate >= 1.0f))) {
                        d4 /= this.mZoomRate;
                    }
                    if (this.mRenderer.isZoomYEnabled() && ((i == 2 || i == 0) && (!this.limitsReachedY || this.mZoomRate >= 1.0f))) {
                        d5 /= this.mZoomRate;
                    }
                } else {
                    if (this.mRenderer.isZoomXEnabled() && !this.limitsReachedX && (i == 1 || i == 0)) {
                        d4 *= this.mZoomRate;
                    }
                    if (this.mRenderer.isZoomYEnabled() && !this.limitsReachedY && (i == 2 || i == 0)) {
                        d5 *= this.mZoomRate;
                    }
                }
                double d12 = d4;
                double d13 = d5;
                if (zoomLimits != null) {
                    d = d3;
                    i2 = i3;
                    zoomInLimitX = Math.min(this.mRenderer.getZoomInLimitX(), zoomLimits[1] - zoomLimits[r9]);
                    zoomInLimitY = Math.min(this.mRenderer.getZoomInLimitY(), zoomLimits[3] - zoomLimits[2]);
                } else {
                    i2 = i3;
                    d = d3;
                    zoomInLimitX = this.mRenderer.getZoomInLimitX();
                    zoomInLimitY = this.mRenderer.getZoomInLimitY();
                }
                double max = Math.max(d12, zoomInLimitX);
                double max2 = Math.max(d13, zoomInLimitY);
                if (this.mRenderer.isZoomXEnabled() && (i == 1 || i == 0)) {
                    double d14 = max / 2.0d;
                    setXRange(d2 - d14, d14 + d2, i2);
                }
                if (this.mRenderer.isZoomYEnabled() && (i == 2 || i == 0)) {
                    double d15 = max2 / 2.0d;
                    setYRange(d - d15, d + d15, i2);
                }
                i3 = i2 + 1;
                r9 = 0;
            }
        } else {
            DefaultRenderer renderer = ((RoundChart) this.mChart).getRenderer();
            if (this.mZoomIn) {
                renderer.setScale(renderer.getScale() * this.mZoomRate);
            } else {
                renderer.setScale(renderer.getScale() / this.mZoomRate);
            }
        }
        notifyZoomListeners(new ZoomEvent(this.mZoomIn, this.mZoomRate));
    }

    private synchronized void notifyZoomListeners(ZoomEvent zoomEvent) {
        Iterator<ZoomListener> it2 = this.mZoomListeners.iterator();
        while (it2.hasNext()) {
            it2.next().zoomApplied(zoomEvent);
        }
    }

    public synchronized void notifyZoomResetListeners() {
        Iterator<ZoomListener> it2 = this.mZoomListeners.iterator();
        while (it2.hasNext()) {
            it2.next().zoomReset();
        }
    }

    public synchronized void addZoomListener(ZoomListener zoomListener) {
        this.mZoomListeners.add(zoomListener);
    }

    public synchronized void removeZoomListener(ZoomListener zoomListener) {
        this.mZoomListeners.remove(zoomListener);
    }
}
