package pub.devrel.easypermissions.helper;

import android.app.Activity;
import android.content.Context;
import android.os.Build;
import androidx.appcompat.app.AppCompatActivity;
import androidx.fragment.app.Fragment;
import java.util.Iterator;
import java.util.List;

/* loaded from: classes2.dex */
public abstract class PermissionHelper<T> {
    private static final String TAG = "PermissionHelper";
    private T mHost;

    public abstract void directRequestPermissions(int i, String... strArr);

    public abstract Context getContext();

    public abstract boolean shouldShowRequestPermissionRationale(String str);

    public abstract void showRequestPermissionRationale(String str, int i, int i2, int i3, String... strArr);

    public static PermissionHelper newInstance(Activity activity) {
        if (Build.VERSION.SDK_INT < 23) {
            return new LowApiPermissionsHelper(activity);
        }
        if (activity instanceof AppCompatActivity) {
            return new AppCompatActivityPermissionHelper((AppCompatActivity) activity);
        }
        return new ActivityPermissionHelper(activity);
    }

    public static PermissionHelper newInstance(Fragment fragment) {
        if (Build.VERSION.SDK_INT < 23) {
            return new LowApiPermissionsHelper(fragment);
        }
        return new SupportFragmentPermissionHelper(fragment);
    }

    public static PermissionHelper newInstance(android.app.Fragment fragment) {
        if (Build.VERSION.SDK_INT < 23) {
            return new LowApiPermissionsHelper(fragment);
        }
        return new FrameworkFragmentPermissionHelper(fragment);
    }

    public PermissionHelper(T t) {
        this.mHost = t;
    }

    public boolean shouldShowRationale(String... strArr) {
        for (String str : strArr) {
            if (shouldShowRequestPermissionRationale(str)) {
                return true;
            }
        }
        return false;
    }

    public void requestPermissions(String str, int i, int i2, int i3, String... strArr) {
        if (shouldShowRationale(strArr)) {
            showRequestPermissionRationale(str, i, i2, i3, strArr);
        } else {
            directRequestPermissions(i3, strArr);
        }
    }

    public boolean somePermissionPermanentlyDenied(List<String> list) {
        Iterator<String> it2 = list.iterator();
        while (it2.hasNext()) {
            if (permissionPermanentlyDenied(it2.next())) {
                return true;
            }
        }
        return false;
    }

    public boolean permissionPermanentlyDenied(String str) {
        return !shouldShowRequestPermissionRationale(str);
    }

    public boolean somePermissionDenied(String... strArr) {
        return shouldShowRationale(strArr);
    }

    public T getHost() {
        return this.mHost;
    }
}
